{
 "cells": [
  {
   "cell_type": "code",
   "execution_count": 97,
   "id": "bc077a0d-3cac-4f63-8b00-fa6d878fe2a7",
   "metadata": {
    "editable": true,
    "slideshow": {
     "slide_type": ""
    },
    "tags": [
     "remove-cell"
    ]
   },
   "outputs": [],
   "source": [
    "import pandas as pd\n",
    "import altair as alt\n",
    "artefacts_df = pd.read_csv(\"artefacts-overview-stats.csv\")\n",
    "\n",
    "artefacts_non_nature_df = artefacts_df.loc[artefacts_df['topic'] != 'nature']\n"
   ]
  },
  {
   "cell_type": "markdown",
   "id": "e5ad9c98-1a94-420e-87d2-1db0e880ed67",
   "metadata": {
    "editable": true,
    "slideshow": {
     "slide_type": ""
    },
    "tags": []
   },
   "source": [
    "## Artefacts "
   ]
  },
  {
   "cell_type": "markdown",
   "id": "11b0b477-1321-45ac-8b8f-a20fbbecd0f3",
   "metadata": {
    "editable": true,
    "slideshow": {
     "slide_type": ""
    },
    "tags": [
     "remove-cell"
    ]
   },
   "source": [
    "\n",
    "This is a doomed attempt to summarise the number of artefacts (see below for definitions) held in UK public collections. Doomed because, to quote from the British Library annual report 2023/2024 - 'in the absence of a consensus about what constitutes a single item it is not possible to reach a definitive statement of the size of the collection'. Added to that is also what is considered an artefact - are all museum objects, all items held in a library (every copy held of Joyce's Ulysses, even one printed last year?), any item in an archive to be counted? Should heritage buildings be counted as well, and do we say a castle is one item on par with a manuscript or painting ?\n",
    "\n",
    "But regardless of this, as the TaNC report also tried to set out counts of the national collection, this is an attempt to visualise this more, to give \n",
    "\n",
    "Definitions (about which we can no doubt all politely argue forever about at some agreeable venue someday):\n",
    "\n",
    "  * artefacts - the physical *thing* considered to be cultural heritage\n",
    "  * catalogued record - the inventory level digital catalalogue record for the artefact (for museum, library and archives) or collection of artefacts (for archives)\n",
    "  * enriched record - the richer (I'm not even going to try give a definition of what richer even means - does fully catalogued mean nothing more can ever be said?) catalogued record for the item (for museum, library and archives) or collection of artefacts (for archives)\n",
    "  * digitised record - catalogued (enriched or otherwise) and an image (or other media) of the artefact (for museum, library and archives items) \n",
    "\n",
    "In these overview pages we givbe various breakdowns of the stats for each of the above and try to tease out\n",
    "a sunmmary of the state of this in the UK cultural heritage collections. There are then\n",
    "\n",
    "Summary\n",
    "  * Overview (artefacts, catalogued records, objects, library, archive)\n",
    "  * Sub collections records (granual version of above)\n",
    "  * Sector level records (library,museum,archive)\n",
    "  * Institution level records (per institution pages)\n",
    "\n",
    "(we are not breaking down collection into sub collections for artefacts as that's getting too complex and\n",
    "not really comparable so not useful for data visualisation)\n",
    "    \n",
    "Progress (i.e. showing difference between current and previous)\n",
    "  * Overview Progress - tracking change over time\n",
    "  * sub collections progress\n",
    "  * Sector Progress\n",
    "  * Institution level progress\n",
    "\n",
    "Uncertainty Level\n",
    "\n",
    "  * Level 1 - unavoidable inherent uncertainty\n",
    "  * Level 2 - uncertainty of number of artefacts\n",
    "  * Level 3 - uncertainty of cataloging type\n",
    "  * Level 4 - uncertainty of number of records\n",
    "  * Level 5 - uncertainty of number of published records"
   ]
  },
  {
   "cell_type": "markdown",
   "id": "581931cf-7042-4193-8c5b-62ba2c54b9a9",
   "metadata": {
    "editable": true,
    "slideshow": {
     "slide_type": ""
    },
    "tags": []
   },
   "source": [
    "## Artefacts by topic"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 91,
   "id": "03c7e003-5b41-45b0-80ca-b5603651e548",
   "metadata": {
    "editable": true,
    "slideshow": {
     "slide_type": ""
    },
    "tags": [
     "remove-input",
     "full-size"
    ]
   },
   "outputs": [
    {
     "data": {
      "text/html": [
       "\n",
       "<style>\n",
       "  #altair-viz-3c07a04a6d0348608d56c32aa445ebb5.vega-embed {\n",
       "    width: 100%;\n",
       "    display: flex;\n",
       "  }\n",
       "\n",
       "  #altair-viz-3c07a04a6d0348608d56c32aa445ebb5.vega-embed details,\n",
       "  #altair-viz-3c07a04a6d0348608d56c32aa445ebb5.vega-embed details summary {\n",
       "    position: relative;\n",
       "  }\n",
       "</style>\n",
       "<div id=\"altair-viz-3c07a04a6d0348608d56c32aa445ebb5\"></div>\n",
       "<script type=\"text/javascript\">\n",
       "  var VEGA_DEBUG = (typeof VEGA_DEBUG == \"undefined\") ? {} : VEGA_DEBUG;\n",
       "  (function(spec, embedOpt){\n",
       "    let outputDiv = document.currentScript.previousElementSibling;\n",
       "    if (outputDiv.id !== \"altair-viz-3c07a04a6d0348608d56c32aa445ebb5\") {\n",
       "      outputDiv = document.getElementById(\"altair-viz-3c07a04a6d0348608d56c32aa445ebb5\");\n",
       "    }\n",
       "    const paths = {\n",
       "      \"vega\": \"https://cdn.jsdelivr.net/npm/vega@5?noext\",\n",
       "      \"vega-lib\": \"https://cdn.jsdelivr.net/npm/vega-lib?noext\",\n",
       "      \"vega-lite\": \"https://cdn.jsdelivr.net/npm/vega-lite@5.17.0?noext\",\n",
       "      \"vega-embed\": \"https://cdn.jsdelivr.net/npm/vega-embed@6?noext\",\n",
       "    };\n",
       "\n",
       "    function maybeLoadScript(lib, version) {\n",
       "      var key = `${lib.replace(\"-\", \"\")}_version`;\n",
       "      return (VEGA_DEBUG[key] == version) ?\n",
       "        Promise.resolve(paths[lib]) :\n",
       "        new Promise(function(resolve, reject) {\n",
       "          var s = document.createElement('script');\n",
       "          document.getElementsByTagName(\"head\")[0].appendChild(s);\n",
       "          s.async = true;\n",
       "          s.onload = () => {\n",
       "            VEGA_DEBUG[key] = version;\n",
       "            return resolve(paths[lib]);\n",
       "          };\n",
       "          s.onerror = () => reject(`Error loading script: ${paths[lib]}`);\n",
       "          s.src = paths[lib];\n",
       "        });\n",
       "    }\n",
       "\n",
       "    function showError(err) {\n",
       "      outputDiv.innerHTML = `<div class=\"error\" style=\"color:red;\">${err}</div>`;\n",
       "      throw err;\n",
       "    }\n",
       "\n",
       "    function displayChart(vegaEmbed) {\n",
       "      vegaEmbed(outputDiv, spec, embedOpt)\n",
       "        .catch(err => showError(`Javascript Error: ${err.message}<br>This usually means there's a typo in your chart specification. See the javascript console for the full traceback.`));\n",
       "    }\n",
       "\n",
       "    if(typeof define === \"function\" && define.amd) {\n",
       "      requirejs.config({paths});\n",
       "      require([\"vega-embed\"], displayChart, err => showError(`Error loading script: ${err.message}`));\n",
       "    } else {\n",
       "      maybeLoadScript(\"vega\", \"5\")\n",
       "        .then(() => maybeLoadScript(\"vega-lite\", \"5.17.0\"))\n",
       "        .then(() => maybeLoadScript(\"vega-embed\", \"6\"))\n",
       "        .catch(showError)\n",
       "        .then(() => displayChart(vegaEmbed));\n",
       "    }\n",
       "  })({\"config\": {\"view\": {\"continuousWidth\": 300, \"continuousHeight\": 300}, \"numberFormat\": \".2s\"}, \"data\": {\"name\": \"data-a0a49f43756cc8ba5f025e1441921ad9\"}, \"mark\": {\"type\": \"bar\"}, \"encoding\": {\"color\": {\"field\": \"institution\", \"legend\": {\"columns\": 5, \"orient\": \"bottom\"}, \"sort\": \"descending\", \"type\": \"nominal\"}, \"column\": {\"field\": \"precision\", \"type\": \"ordinal\"}, \"tooltip\": [{\"field\": \"institution\", \"type\": \"nominal\"}, {\"field\": \"artefact_count\", \"type\": \"quantitative\"}], \"x\": {\"field\": \"artefact_count\", \"type\": \"quantitative\"}, \"y\": {\"field\": \"topic\", \"type\": \"nominal\"}}, \"resolve\": {\"scale\": {\"x\": \"independent\"}}, \"title\": {\"text\": \"Collection Size (Artefacts) by topic\", \"anchor\": \"middle\"}, \"width\": 900, \"$schema\": \"https://vega.github.io/schema/vega-lite/v5.17.0.json\", \"datasets\": {\"data-a0a49f43756cc8ba5f025e1441921ad9\": [{\"institution\": \"Oxford University\", \"sector\": \"university\", \"type\": \"university\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 22530000}, {\"institution\": \"University of Cambridge\", \"sector\": \"university\", \"type\": \"university\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 4007000}, {\"institution\": \"Durham University\", \"sector\": \"university\", \"type\": \"university\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 106000}, {\"institution\": \"University College London\", \"sector\": \"university\", \"type\": \"university\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 164000}, {\"institution\": \"University of Manchester\", \"sector\": \"university\", \"type\": \"university\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 8560000}, {\"institution\": \"King's College London\", \"sector\": \"university\", \"type\": \"university\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 200000}, {\"institution\": \"University of Birmingham\", \"sector\": \"university\", \"type\": \"university\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 4500000}, {\"institution\": \"Unversity of Warwick\", \"sector\": \"university\", \"type\": \"university\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 16000}, {\"institution\": \"Manchester Metropolitan Unversity\", \"sector\": \"university\", \"type\": \"university\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 0}, {\"institution\": \"Swansea University\", \"sector\": \"university\", \"type\": \"university\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 1700}, {\"institution\": \"University of Brighton\", \"sector\": \"university\", \"type\": \"university\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 50000}, {\"institution\": \"SOAS, University of London\", \"sector\": \"university\", \"type\": \"university\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 60000}, {\"institution\": \"University of Aberdeen\", \"sector\": \"university\", \"type\": \"university\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 530000}, {\"institution\": \"University of Bristol\", \"sector\": \"university\", \"type\": \"university\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 100000}, {\"institution\": \"University of Leeds\", \"sector\": \"university\", \"type\": \"university\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 350000}, {\"institution\": \"University of Sheffield\", \"sector\": \"university\", \"type\": \"university\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 30000}, {\"institution\": \"University of St Andrews\", \"sector\": \"university\", \"type\": \"university\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 200000}, {\"institution\": \"Royal College of Surgeons\", \"sector\": \"university\", \"type\": \"university\", \"topic\": \"medicine\", \"precision\": \"estimate\", \"artefact_count\": 3500}, {\"institution\": \"British Library\", \"sector\": \"library\", \"type\": \"library\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 45810000}, {\"institution\": \"Chetham's Library\", \"sector\": \"library\", \"type\": \"library\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 121041}, {\"institution\": \"Glasgow Woman's Library\", \"sector\": \"library\", \"type\": \"library\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 0}, {\"institution\": \"Lambeth Palace Library\", \"sector\": \"library\", \"type\": \"library\", \"topic\": \"theology\", \"precision\": \"estimate\", \"artefact_count\": 186200}, {\"institution\": \"National Library of Wales\", \"sector\": \"library\", \"type\": \"library\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 7540000}, {\"institution\": \"National Library of Scotland\", \"sector\": \"library\", \"type\": \"library\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 37000000}, {\"institution\": \"Amgueddfa Cymru (National Museum Wales)\", \"sector\": \"national\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 5319585}, {\"institution\": \"Historic Royal Palaces\", \"sector\": \"national\", \"type\": \"building\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 60000}, {\"institution\": \"National Football Museum\", \"sector\": \"national\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 40000}, {\"institution\": \"National Justice Museum\", \"sector\": \"national\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 40000}, {\"institution\": \"National Mining Museum Scotland\", \"sector\": \"national\", \"type\": \"museum\", \"topic\": \"industry\", \"precision\": \"estimate\", \"artefact_count\": 100000}, {\"institution\": \"National Museum of the Royal Navy\", \"sector\": \"national\", \"type\": \"museum\", \"topic\": \"maritime\", \"precision\": \"estimate\", \"artefact_count\": 2500000}, {\"institution\": \"National Museums NI\", \"sector\": \"national\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 1400000}, {\"institution\": \"National Museums Scotland\", \"sector\": \"national\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 12000000}, {\"institution\": \"National Tramway Museum\", \"sector\": \"national\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 46690}, {\"institution\": \"National Trust\", \"sector\": \"national\", \"type\": \"building\", \"topic\": \"art\", \"precision\": \"estimate\", \"artefact_count\": 1000000}, {\"institution\": \"National Trust for Scotland\", \"sector\": \"national\", \"type\": \"building\", \"topic\": \"art\", \"precision\": \"estimate\", \"artefact_count\": 300000}, {\"institution\": \"National Waterways Museum\", \"sector\": \"national\", \"type\": \"building\", \"topic\": \"transport\", \"precision\": \"estimate\", \"artefact_count\": 150000}, {\"institution\": \"Government Art Collection\", \"sector\": \"national\", \"type\": \"museum\", \"topic\": \"art\", \"precision\": \"estimate\", \"artefact_count\": 15000}, {\"institution\": \"Historic Environment Scotland\", \"sector\": \"national\", \"type\": \"museum\", \"topic\": \"heritage\", \"precision\": \"estimate\", \"artefact_count\": 41000}, {\"institution\": \"People's History Museum\", \"sector\": \"national\", \"type\": \"museum\", \"topic\": \"social\", \"precision\": \"estimate\", \"artefact_count\": 5680}, {\"institution\": \"Portable Antiquities Scheme\", \"sector\": \"national\", \"type\": \"museum\", \"topic\": \"archaeology\", \"precision\": \"estimate\", \"artefact_count\": 1751232}, {\"institution\": \"Royal Air Force Museum\", \"sector\": \"national\", \"type\": \"museum\", \"topic\": \"military\", \"precision\": \"estimate\", \"artefact_count\": 1300000}, {\"institution\": \"Royal Botanic Gardens Kew\", \"sector\": \"national\", \"type\": \"museum\", \"topic\": \"nature\", \"precision\": \"estimate\", \"artefact_count\": 7000000}, {\"institution\": \"Royal Collection\", \"sector\": \"national\", \"type\": \"museum\", \"topic\": \"art\", \"precision\": \"estimate\", \"artefact_count\": 1000000}, {\"institution\": \"Staffordshire Archive and Heritage\", \"sector\": \"regional\", \"type\": \"mixed\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 0}, {\"institution\": \"Courtauld Gallery\", \"sector\": \"independent\", \"type\": \"gallery\", \"topic\": \"art\", \"precision\": \"estimate\", \"artefact_count\": 33501}, {\"institution\": \"Dulwich Picture Gallery\", \"sector\": \"independent\", \"type\": \"gallery\", \"topic\": \"art\", \"precision\": \"estimate\", \"artefact_count\": 600}, {\"institution\": \"Manchester Art Gallery\", \"sector\": \"independent\", \"type\": \"gallery\", \"topic\": \"art\", \"precision\": \"estimate\", \"artefact_count\": 46000}, {\"institution\": \"National Galleries Scotland\", \"sector\": \"independent\", \"type\": \"gallery\", \"topic\": \"art\", \"precision\": \"estimate\", \"artefact_count\": 120000}, {\"institution\": \"William Morris Gallery\", \"sector\": \"regional\", \"type\": \"gallery\", \"topic\": \"art\", \"precision\": \"estimate\", \"artefact_count\": 10000}, {\"institution\": \"Linnaean Society\", \"sector\": \"societies\", \"type\": \"society\", \"topic\": \"nature\", \"precision\": \"estimate\", \"artefact_count\": 20268}, {\"institution\": \"Bowes Museum\", \"sector\": \"independent\", \"type\": \"museum\", \"topic\": \"art\", \"precision\": \"estimate\", \"artefact_count\": 30000}, {\"institution\": \"Britten Pears\", \"sector\": \"independent\", \"type\": \"museum\", \"topic\": \"art\", \"precision\": \"estimate\", \"artefact_count\": 1200}, {\"institution\": \"Chatham Historic Dockyard\", \"sector\": \"independent\", \"type\": \"building\", \"topic\": \"maritime\", \"precision\": \"estimate\", \"artefact_count\": 70000}, {\"institution\": \"English Heritage Trust\", \"sector\": \"independent\", \"type\": \"building\", \"topic\": \"history\", \"precision\": \"estimate\", \"artefact_count\": 700000}, {\"institution\": \"Gordon Highlanders Museum\", \"sector\": \"independent\", \"type\": \"museum\", \"topic\": \"military\", \"precision\": \"estimate\", \"artefact_count\": 40000}, {\"institution\": \"Ironbridge Gorge Museum Trust\", \"sector\": \"independent\", \"type\": \"museum\", \"topic\": \"industry\", \"precision\": \"estimate\", \"artefact_count\": 400000}, {\"institution\": \"Jewish Museum London\", \"sector\": \"independent\", \"type\": \"museum\", \"topic\": \"social\", \"precision\": \"estimate\", \"artefact_count\": 40000}, {\"institution\": \"London Transport Museum\", \"sector\": \"independent\", \"type\": \"museum\", \"topic\": \"transport\", \"precision\": \"estimate\", \"artefact_count\": 500000}, {\"institution\": \"Manchester Jewish Museum\", \"sector\": \"independent\", \"type\": \"museum\", \"topic\": \"social\", \"precision\": \"estimate\", \"artefact_count\": 31000}, {\"institution\": \"Mary Rose Trust\", \"sector\": \"independent\", \"type\": \"museum\", \"topic\": \"maritime\", \"precision\": \"estimate\", \"artefact_count\": 19000}, {\"institution\": \"Media Archive for Central England (MACE)\", \"sector\": \"independent\", \"type\": \"archive\", \"topic\": \"media\", \"precision\": \"estimate\", \"artefact_count\": 65000}, {\"institution\": \"Food Museum\", \"sector\": \"independent\", \"type\": \"museum\", \"topic\": \"social\", \"precision\": \"estimate\", \"artefact_count\": 40000}, {\"institution\": \"Museum of Freemasonry\", \"sector\": \"independent\", \"type\": \"museum\", \"topic\": \"social\", \"precision\": \"estimate\", \"artefact_count\": 90000}, {\"institution\": \"Museum of Lead Mining\", \"sector\": \"independent\", \"type\": \"museum\", \"topic\": \"industry\", \"precision\": \"estimate\", \"artefact_count\": 2572}, {\"institution\": \"Museum of Scottish Railways\", \"sector\": \"independent\", \"type\": \"museum\", \"topic\": \"industry\", \"precision\": \"estimate\", \"artefact_count\": 50000}, {\"institution\": \"Paxton Trust\", \"sector\": \"independent\", \"type\": \"building\", \"topic\": \"art\", \"precision\": \"estimate\", \"artefact_count\": 3754}, {\"institution\": \"Pier Arts Centre\", \"sector\": \"independent\", \"type\": \"gallery\", \"topic\": \"art\", \"precision\": \"estimate\", \"artefact_count\": 180}, {\"institution\": \"Postal Museum\", \"sector\": \"independent\", \"type\": \"museum\", \"topic\": \"social\", \"precision\": \"estimate\", \"artefact_count\": 60000}, {\"institution\": \"Royal Artillery Museum\", \"sector\": \"independent\", \"type\": \"museum\", \"topic\": \"military\", \"precision\": \"estimate\", \"artefact_count\": 30000}, {\"institution\": \"Royal Engineers Museum\", \"sector\": \"independent\", \"type\": \"museum\", \"topic\": \"military\", \"precision\": \"estimate\", \"artefact_count\": 1000000}, {\"institution\": \"Royal Scottish Academy of Art & Architecture\", \"sector\": \"independent\", \"type\": \"museum\", \"topic\": \"art\", \"precision\": \"estimate\", \"artefact_count\": 9000}, {\"institution\": \"Scottish Fisheries Museum\", \"sector\": \"independent\", \"type\": \"museum\", \"topic\": \"maritime\", \"precision\": \"estimate\", \"artefact_count\": 66000}, {\"institution\": \"Thackray Museum of Medicine\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"medicine\", \"precision\": \"estimate\", \"artefact_count\": 75000}, {\"institution\": \"Tuillie House Museum and Art Gallery\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 1000000}, {\"institution\": \"Wellcome Collection\", \"sector\": \"independent\", \"type\": \"museum\", \"topic\": \"medicine\", \"precision\": \"estimate\", \"artefact_count\": 2250000}, {\"institution\": \"Wordsworth Museum Collection\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"literature\", \"precision\": \"estimate\", \"artefact_count\": 68000}, {\"institution\": \"Aberdeenshire Council Museums\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 250000}, {\"institution\": \"Barnsley Museums\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 711400}, {\"institution\": \"Birmingham Museums Trust\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"art\", \"precision\": \"estimate\", \"artefact_count\": 800000}, {\"institution\": \"Black Country Living Museum\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"history\", \"precision\": \"estimate\", \"artefact_count\": 80000}, {\"institution\": \"Bradford District Museums & Galleries\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 837837}, {\"institution\": \"Bristol Museums\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 2000000}, {\"institution\": \"Culture Coventry\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 1000000}, {\"institution\": \"Culture Perth and Kinross\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 500000}, {\"institution\": \"Culture Trust Luton\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 1105051}, {\"institution\": \"Dundee Heritage Trust\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 0}, {\"institution\": \"Elgin Museum\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 36000}, {\"institution\": \"Glasgow Museums\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 1000000}, {\"institution\": \"Heritage Doncaster\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 406750}, {\"institution\": \"Highland Folk Museum\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"social\", \"precision\": \"estimate\", \"artefact_count\": 10000}, {\"institution\": \"Leeds Museums & Galleries\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 1300000}, {\"institution\": \"Leicester Museums\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 1500000}, {\"institution\": \"Manchester Art Gallery\", \"sector\": \"regional\", \"type\": \"gallery\", \"topic\": \"art\", \"precision\": \"estimate\", \"artefact_count\": 50000}, {\"institution\": \"Edinburgh Museums\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 220000}, {\"institution\": \"Museums Northumberland\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 25000}, {\"institution\": \"Northampton Museums\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 44024}, {\"institution\": \"Orkney Museums\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 100000}, {\"institution\": \"Poole Museums\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 50000}, {\"institution\": \"Potteries Museum and Art Gallery\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"art\", \"precision\": \"estimate\", \"artefact_count\": 1000000}, {\"institution\": \"Preston Park Museum & Grounds\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"social\", \"precision\": \"estimate\", \"artefact_count\": 100000}, {\"institution\": \"Ripon Museums\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"social\", \"precision\": \"estimate\", \"artefact_count\": 9000}, {\"institution\": \"Royal Albert Memorial Museum\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 1000000}, {\"institution\": \"Salisbury Museum\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 100000}, {\"institution\": \"St Helens Borough Council\", \"sector\": \"regional\", \"type\": \"archive\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 0}, {\"institution\": \"Sunderland Museum & Winter Gardens' Collection\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 108000}, {\"institution\": \"Wakefield Museums and Castles Collections\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 111000}, {\"institution\": \"Weald and Downland Living Museum\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 15000}, {\"institution\": \"York Museums Trust\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 0}, {\"institution\": \"Victoria & Albert Museum\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"art\", \"precision\": \"estimate\", \"artefact_count\": 2800000}, {\"institution\": \"Science Museum Group\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"science\", \"precision\": \"estimate\", \"artefact_count\": 7360793}, {\"institution\": \"Museum of the Home\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"history\", \"precision\": \"estimate\", \"artefact_count\": 40000}, {\"institution\": \"Horniman Museum\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"history\", \"precision\": \"estimate\", \"artefact_count\": 350000}, {\"institution\": \"Imperial War Museums\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"history\", \"precision\": \"estimate\", \"artefact_count\": 1000000}, {\"institution\": \"National Gallery\", \"sector\": \"dcms\", \"type\": \"gallery\", \"topic\": \"art\", \"precision\": \"estimate\", \"artefact_count\": 2626}, {\"institution\": \"National Museums Liverpool\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"history\", \"precision\": \"estimate\", \"artefact_count\": 4000000}, {\"institution\": \"National Portrait Gallery\", \"sector\": \"dcms\", \"type\": \"gallery\", \"topic\": \"art\", \"precision\": \"estimate\", \"artefact_count\": 350000}, {\"institution\": \"Royal Armouries\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"history\", \"precision\": \"estimate\", \"artefact_count\": 70000}, {\"institution\": \"Royal Museums Greenwich\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"history\", \"precision\": \"estimate\", \"artefact_count\": 3000000}, {\"institution\": \"Sir John Soane's Museum\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"history\", \"precision\": \"estimate\", \"artefact_count\": 52000}, {\"institution\": \"Tate Gallery Group\", \"sector\": \"dcms\", \"type\": \"gallery\", \"topic\": \"art\", \"precision\": \"estimate\", \"artefact_count\": 70000}, {\"institution\": \"The Wallace Collection\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"art\", \"precision\": \"estimate\", \"artefact_count\": 5637}, {\"institution\": \"British Museum\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"history\", \"precision\": \"estimate\", \"artefact_count\": 8000000}]}}, {\"mode\": \"vega-lite\"});\n",
       "</script>"
      ],
      "text/plain": [
       "alt.Chart(...)"
      ]
     },
     "execution_count": 91,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "title = alt.TitleParams('Collection Size (Artefacts) by topic', anchor='middle')\n",
    "alt.Chart(artefacts_df, title=title).mark_bar().encode(\n",
    "    alt.Color('institution:N', sort='descending', legend=alt.Legend(orient='bottom',columns=5)),\n",
    "    column='precision:O',\n",
    "    x='artefact_count:Q',\n",
    "    tooltip=['institution', 'artefact_count'],\n",
    "    y='topic:N',\n",
    ").properties(width=900).resolve_scale(x='independent').configure(numberFormat='.2s')"
   ]
  },
  {
   "cell_type": "markdown",
   "id": "c7705140-9c09-45a6-a178-4806462c9ca6",
   "metadata": {
    "editable": true,
    "slideshow": {
     "slide_type": ""
    },
    "tags": []
   },
   "source": [
    "## Artefacts by sector\n",
    "\n",
    "Showing the distribution of artefacts (a cultural heritage item of any type) on different topic held in each sector."
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 89,
   "id": "89073ee0-2028-414e-a96f-51f19b3396b8",
   "metadata": {
    "editable": true,
    "slideshow": {
     "slide_type": ""
    },
    "tags": [
     "remove-input",
     "full-size"
    ]
   },
   "outputs": [
    {
     "data": {
      "text/html": [
       "\n",
       "<style>\n",
       "  #altair-viz-35822e7422b94c1492f8aa15290f4abc.vega-embed {\n",
       "    width: 100%;\n",
       "    display: flex;\n",
       "  }\n",
       "\n",
       "  #altair-viz-35822e7422b94c1492f8aa15290f4abc.vega-embed details,\n",
       "  #altair-viz-35822e7422b94c1492f8aa15290f4abc.vega-embed details summary {\n",
       "    position: relative;\n",
       "  }\n",
       "</style>\n",
       "<div id=\"altair-viz-35822e7422b94c1492f8aa15290f4abc\"></div>\n",
       "<script type=\"text/javascript\">\n",
       "  var VEGA_DEBUG = (typeof VEGA_DEBUG == \"undefined\") ? {} : VEGA_DEBUG;\n",
       "  (function(spec, embedOpt){\n",
       "    let outputDiv = document.currentScript.previousElementSibling;\n",
       "    if (outputDiv.id !== \"altair-viz-35822e7422b94c1492f8aa15290f4abc\") {\n",
       "      outputDiv = document.getElementById(\"altair-viz-35822e7422b94c1492f8aa15290f4abc\");\n",
       "    }\n",
       "    const paths = {\n",
       "      \"vega\": \"https://cdn.jsdelivr.net/npm/vega@5?noext\",\n",
       "      \"vega-lib\": \"https://cdn.jsdelivr.net/npm/vega-lib?noext\",\n",
       "      \"vega-lite\": \"https://cdn.jsdelivr.net/npm/vega-lite@5.17.0?noext\",\n",
       "      \"vega-embed\": \"https://cdn.jsdelivr.net/npm/vega-embed@6?noext\",\n",
       "    };\n",
       "\n",
       "    function maybeLoadScript(lib, version) {\n",
       "      var key = `${lib.replace(\"-\", \"\")}_version`;\n",
       "      return (VEGA_DEBUG[key] == version) ?\n",
       "        Promise.resolve(paths[lib]) :\n",
       "        new Promise(function(resolve, reject) {\n",
       "          var s = document.createElement('script');\n",
       "          document.getElementsByTagName(\"head\")[0].appendChild(s);\n",
       "          s.async = true;\n",
       "          s.onload = () => {\n",
       "            VEGA_DEBUG[key] = version;\n",
       "            return resolve(paths[lib]);\n",
       "          };\n",
       "          s.onerror = () => reject(`Error loading script: ${paths[lib]}`);\n",
       "          s.src = paths[lib];\n",
       "        });\n",
       "    }\n",
       "\n",
       "    function showError(err) {\n",
       "      outputDiv.innerHTML = `<div class=\"error\" style=\"color:red;\">${err}</div>`;\n",
       "      throw err;\n",
       "    }\n",
       "\n",
       "    function displayChart(vegaEmbed) {\n",
       "      vegaEmbed(outputDiv, spec, embedOpt)\n",
       "        .catch(err => showError(`Javascript Error: ${err.message}<br>This usually means there's a typo in your chart specification. See the javascript console for the full traceback.`));\n",
       "    }\n",
       "\n",
       "    if(typeof define === \"function\" && define.amd) {\n",
       "      requirejs.config({paths});\n",
       "      require([\"vega-embed\"], displayChart, err => showError(`Error loading script: ${err.message}`));\n",
       "    } else {\n",
       "      maybeLoadScript(\"vega\", \"5\")\n",
       "        .then(() => maybeLoadScript(\"vega-lite\", \"5.17.0\"))\n",
       "        .then(() => maybeLoadScript(\"vega-embed\", \"6\"))\n",
       "        .catch(showError)\n",
       "        .then(() => displayChart(vegaEmbed));\n",
       "    }\n",
       "  })({\"config\": {\"view\": {\"continuousWidth\": 300, \"continuousHeight\": 300}, \"numberFormat\": \".2s\"}, \"data\": {\"name\": \"data-a0a49f43756cc8ba5f025e1441921ad9\"}, \"mark\": {\"type\": \"bar\"}, \"encoding\": {\"color\": {\"field\": \"institution\", \"legend\": {\"columns\": 4, \"orient\": \"bottom\"}, \"type\": \"nominal\"}, \"column\": {\"field\": \"sector\", \"type\": \"nominal\"}, \"tooltip\": [{\"field\": \"institution\", \"type\": \"nominal\"}, {\"field\": \"artefact_count\", \"type\": \"quantitative\"}], \"x\": {\"field\": \"artefact_count\", \"type\": \"quantitative\"}, \"y\": {\"field\": \"topic\", \"type\": \"nominal\"}}, \"resolve\": {\"scale\": {\"x\": \"independent\"}}, \"title\": {\"text\": \"Artefacts by sector\", \"anchor\": \"middle\"}, \"width\": 225, \"$schema\": \"https://vega.github.io/schema/vega-lite/v5.17.0.json\", \"datasets\": {\"data-a0a49f43756cc8ba5f025e1441921ad9\": [{\"institution\": \"Oxford University\", \"sector\": \"university\", \"type\": \"university\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 22530000}, {\"institution\": \"University of Cambridge\", \"sector\": \"university\", \"type\": \"university\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 4007000}, {\"institution\": \"Durham University\", \"sector\": \"university\", \"type\": \"university\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 106000}, {\"institution\": \"University College London\", \"sector\": \"university\", \"type\": \"university\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 164000}, {\"institution\": \"University of Manchester\", \"sector\": \"university\", \"type\": \"university\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 8560000}, {\"institution\": \"King's College London\", \"sector\": \"university\", \"type\": \"university\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 200000}, {\"institution\": \"University of Birmingham\", \"sector\": \"university\", \"type\": \"university\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 4500000}, {\"institution\": \"Unversity of Warwick\", \"sector\": \"university\", \"type\": \"university\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 16000}, {\"institution\": \"Manchester Metropolitan Unversity\", \"sector\": \"university\", \"type\": \"university\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 0}, {\"institution\": \"Swansea University\", \"sector\": \"university\", \"type\": \"university\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 1700}, {\"institution\": \"University of Brighton\", \"sector\": \"university\", \"type\": \"university\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 50000}, {\"institution\": \"SOAS, University of London\", \"sector\": \"university\", \"type\": \"university\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 60000}, {\"institution\": \"University of Aberdeen\", \"sector\": \"university\", \"type\": \"university\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 530000}, {\"institution\": \"University of Bristol\", \"sector\": \"university\", \"type\": \"university\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 100000}, {\"institution\": \"University of Leeds\", \"sector\": \"university\", \"type\": \"university\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 350000}, {\"institution\": \"University of Sheffield\", \"sector\": \"university\", \"type\": \"university\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 30000}, {\"institution\": \"University of St Andrews\", \"sector\": \"university\", \"type\": \"university\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 200000}, {\"institution\": \"Royal College of Surgeons\", \"sector\": \"university\", \"type\": \"university\", \"topic\": \"medicine\", \"precision\": \"estimate\", \"artefact_count\": 3500}, {\"institution\": \"British Library\", \"sector\": \"library\", \"type\": \"library\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 45810000}, {\"institution\": \"Chetham's Library\", \"sector\": \"library\", \"type\": \"library\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 121041}, {\"institution\": \"Glasgow Woman's Library\", \"sector\": \"library\", \"type\": \"library\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 0}, {\"institution\": \"Lambeth Palace Library\", \"sector\": \"library\", \"type\": \"library\", \"topic\": \"theology\", \"precision\": \"estimate\", \"artefact_count\": 186200}, {\"institution\": \"National Library of Wales\", \"sector\": \"library\", \"type\": \"library\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 7540000}, {\"institution\": \"National Library of Scotland\", \"sector\": \"library\", \"type\": \"library\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 37000000}, {\"institution\": \"Amgueddfa Cymru (National Museum Wales)\", \"sector\": \"national\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 5319585}, {\"institution\": \"Historic Royal Palaces\", \"sector\": \"national\", \"type\": \"building\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 60000}, {\"institution\": \"National Football Museum\", \"sector\": \"national\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 40000}, {\"institution\": \"National Justice Museum\", \"sector\": \"national\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 40000}, {\"institution\": \"National Mining Museum Scotland\", \"sector\": \"national\", \"type\": \"museum\", \"topic\": \"industry\", \"precision\": \"estimate\", \"artefact_count\": 100000}, {\"institution\": \"National Museum of the Royal Navy\", \"sector\": \"national\", \"type\": \"museum\", \"topic\": \"maritime\", \"precision\": \"estimate\", \"artefact_count\": 2500000}, {\"institution\": \"National Museums NI\", \"sector\": \"national\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 1400000}, {\"institution\": \"National Museums Scotland\", \"sector\": \"national\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 12000000}, {\"institution\": \"National Tramway Museum\", \"sector\": \"national\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 46690}, {\"institution\": \"National Trust\", \"sector\": \"national\", \"type\": \"building\", \"topic\": \"art\", \"precision\": \"estimate\", \"artefact_count\": 1000000}, {\"institution\": \"National Trust for Scotland\", \"sector\": \"national\", \"type\": \"building\", \"topic\": \"art\", \"precision\": \"estimate\", \"artefact_count\": 300000}, {\"institution\": \"National Waterways Museum\", \"sector\": \"national\", \"type\": \"building\", \"topic\": \"transport\", \"precision\": \"estimate\", \"artefact_count\": 150000}, {\"institution\": \"Government Art Collection\", \"sector\": \"national\", \"type\": \"museum\", \"topic\": \"art\", \"precision\": \"estimate\", \"artefact_count\": 15000}, {\"institution\": \"Historic Environment Scotland\", \"sector\": \"national\", \"type\": \"museum\", \"topic\": \"heritage\", \"precision\": \"estimate\", \"artefact_count\": 41000}, {\"institution\": \"People's History Museum\", \"sector\": \"national\", \"type\": \"museum\", \"topic\": \"social\", \"precision\": \"estimate\", \"artefact_count\": 5680}, {\"institution\": \"Portable Antiquities Scheme\", \"sector\": \"national\", \"type\": \"museum\", \"topic\": \"archaeology\", \"precision\": \"estimate\", \"artefact_count\": 1751232}, {\"institution\": \"Royal Air Force Museum\", \"sector\": \"national\", \"type\": \"museum\", \"topic\": \"military\", \"precision\": \"estimate\", \"artefact_count\": 1300000}, {\"institution\": \"Royal Botanic Gardens Kew\", \"sector\": \"national\", \"type\": \"museum\", \"topic\": \"nature\", \"precision\": \"estimate\", \"artefact_count\": 7000000}, {\"institution\": \"Royal Collection\", \"sector\": \"national\", \"type\": \"museum\", \"topic\": \"art\", \"precision\": \"estimate\", \"artefact_count\": 1000000}, {\"institution\": \"Staffordshire Archive and Heritage\", \"sector\": \"regional\", \"type\": \"mixed\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 0}, {\"institution\": \"Courtauld Gallery\", \"sector\": \"independent\", \"type\": \"gallery\", \"topic\": \"art\", \"precision\": \"estimate\", \"artefact_count\": 33501}, {\"institution\": \"Dulwich Picture Gallery\", \"sector\": \"independent\", \"type\": \"gallery\", \"topic\": \"art\", \"precision\": \"estimate\", \"artefact_count\": 600}, {\"institution\": \"Manchester Art Gallery\", \"sector\": \"independent\", \"type\": \"gallery\", \"topic\": \"art\", \"precision\": \"estimate\", \"artefact_count\": 46000}, {\"institution\": \"National Galleries Scotland\", \"sector\": \"independent\", \"type\": \"gallery\", \"topic\": \"art\", \"precision\": \"estimate\", \"artefact_count\": 120000}, {\"institution\": \"William Morris Gallery\", \"sector\": \"regional\", \"type\": \"gallery\", \"topic\": \"art\", \"precision\": \"estimate\", \"artefact_count\": 10000}, {\"institution\": \"Linnaean Society\", \"sector\": \"societies\", \"type\": \"society\", \"topic\": \"nature\", \"precision\": \"estimate\", \"artefact_count\": 20268}, {\"institution\": \"Bowes Museum\", \"sector\": \"independent\", \"type\": \"museum\", \"topic\": \"art\", \"precision\": \"estimate\", \"artefact_count\": 30000}, {\"institution\": \"Britten Pears\", \"sector\": \"independent\", \"type\": \"museum\", \"topic\": \"art\", \"precision\": \"estimate\", \"artefact_count\": 1200}, {\"institution\": \"Chatham Historic Dockyard\", \"sector\": \"independent\", \"type\": \"building\", \"topic\": \"maritime\", \"precision\": \"estimate\", \"artefact_count\": 70000}, {\"institution\": \"English Heritage Trust\", \"sector\": \"independent\", \"type\": \"building\", \"topic\": \"history\", \"precision\": \"estimate\", \"artefact_count\": 700000}, {\"institution\": \"Gordon Highlanders Museum\", \"sector\": \"independent\", \"type\": \"museum\", \"topic\": \"military\", \"precision\": \"estimate\", \"artefact_count\": 40000}, {\"institution\": \"Ironbridge Gorge Museum Trust\", \"sector\": \"independent\", \"type\": \"museum\", \"topic\": \"industry\", \"precision\": \"estimate\", \"artefact_count\": 400000}, {\"institution\": \"Jewish Museum London\", \"sector\": \"independent\", \"type\": \"museum\", \"topic\": \"social\", \"precision\": \"estimate\", \"artefact_count\": 40000}, {\"institution\": \"London Transport Museum\", \"sector\": \"independent\", \"type\": \"museum\", \"topic\": \"transport\", \"precision\": \"estimate\", \"artefact_count\": 500000}, {\"institution\": \"Manchester Jewish Museum\", \"sector\": \"independent\", \"type\": \"museum\", \"topic\": \"social\", \"precision\": \"estimate\", \"artefact_count\": 31000}, {\"institution\": \"Mary Rose Trust\", \"sector\": \"independent\", \"type\": \"museum\", \"topic\": \"maritime\", \"precision\": \"estimate\", \"artefact_count\": 19000}, {\"institution\": \"Media Archive for Central England (MACE)\", \"sector\": \"independent\", \"type\": \"archive\", \"topic\": \"media\", \"precision\": \"estimate\", \"artefact_count\": 65000}, {\"institution\": \"Food Museum\", \"sector\": \"independent\", \"type\": \"museum\", \"topic\": \"social\", \"precision\": \"estimate\", \"artefact_count\": 40000}, {\"institution\": \"Museum of Freemasonry\", \"sector\": \"independent\", \"type\": \"museum\", \"topic\": \"social\", \"precision\": \"estimate\", \"artefact_count\": 90000}, {\"institution\": \"Museum of Lead Mining\", \"sector\": \"independent\", \"type\": \"museum\", \"topic\": \"industry\", \"precision\": \"estimate\", \"artefact_count\": 2572}, {\"institution\": \"Museum of Scottish Railways\", \"sector\": \"independent\", \"type\": \"museum\", \"topic\": \"industry\", \"precision\": \"estimate\", \"artefact_count\": 50000}, {\"institution\": \"Paxton Trust\", \"sector\": \"independent\", \"type\": \"building\", \"topic\": \"art\", \"precision\": \"estimate\", \"artefact_count\": 3754}, {\"institution\": \"Pier Arts Centre\", \"sector\": \"independent\", \"type\": \"gallery\", \"topic\": \"art\", \"precision\": \"estimate\", \"artefact_count\": 180}, {\"institution\": \"Postal Museum\", \"sector\": \"independent\", \"type\": \"museum\", \"topic\": \"social\", \"precision\": \"estimate\", \"artefact_count\": 60000}, {\"institution\": \"Royal Artillery Museum\", \"sector\": \"independent\", \"type\": \"museum\", \"topic\": \"military\", \"precision\": \"estimate\", \"artefact_count\": 30000}, {\"institution\": \"Royal Engineers Museum\", \"sector\": \"independent\", \"type\": \"museum\", \"topic\": \"military\", \"precision\": \"estimate\", \"artefact_count\": 1000000}, {\"institution\": \"Royal Scottish Academy of Art & Architecture\", \"sector\": \"independent\", \"type\": \"museum\", \"topic\": \"art\", \"precision\": \"estimate\", \"artefact_count\": 9000}, {\"institution\": \"Scottish Fisheries Museum\", \"sector\": \"independent\", \"type\": \"museum\", \"topic\": \"maritime\", \"precision\": \"estimate\", \"artefact_count\": 66000}, {\"institution\": \"Thackray Museum of Medicine\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"medicine\", \"precision\": \"estimate\", \"artefact_count\": 75000}, {\"institution\": \"Tuillie House Museum and Art Gallery\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 1000000}, {\"institution\": \"Wellcome Collection\", \"sector\": \"independent\", \"type\": \"museum\", \"topic\": \"medicine\", \"precision\": \"estimate\", \"artefact_count\": 2250000}, {\"institution\": \"Wordsworth Museum Collection\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"literature\", \"precision\": \"estimate\", \"artefact_count\": 68000}, {\"institution\": \"Aberdeenshire Council Museums\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 250000}, {\"institution\": \"Barnsley Museums\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 711400}, {\"institution\": \"Birmingham Museums Trust\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"art\", \"precision\": \"estimate\", \"artefact_count\": 800000}, {\"institution\": \"Black Country Living Museum\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"history\", \"precision\": \"estimate\", \"artefact_count\": 80000}, {\"institution\": \"Bradford District Museums & Galleries\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 837837}, {\"institution\": \"Bristol Museums\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 2000000}, {\"institution\": \"Culture Coventry\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 1000000}, {\"institution\": \"Culture Perth and Kinross\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 500000}, {\"institution\": \"Culture Trust Luton\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 1105051}, {\"institution\": \"Dundee Heritage Trust\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 0}, {\"institution\": \"Elgin Museum\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 36000}, {\"institution\": \"Glasgow Museums\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 1000000}, {\"institution\": \"Heritage Doncaster\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 406750}, {\"institution\": \"Highland Folk Museum\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"social\", \"precision\": \"estimate\", \"artefact_count\": 10000}, {\"institution\": \"Leeds Museums & Galleries\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 1300000}, {\"institution\": \"Leicester Museums\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 1500000}, {\"institution\": \"Manchester Art Gallery\", \"sector\": \"regional\", \"type\": \"gallery\", \"topic\": \"art\", \"precision\": \"estimate\", \"artefact_count\": 50000}, {\"institution\": \"Edinburgh Museums\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 220000}, {\"institution\": \"Museums Northumberland\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 25000}, {\"institution\": \"Northampton Museums\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 44024}, {\"institution\": \"Orkney Museums\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 100000}, {\"institution\": \"Poole Museums\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 50000}, {\"institution\": \"Potteries Museum and Art Gallery\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"art\", \"precision\": \"estimate\", \"artefact_count\": 1000000}, {\"institution\": \"Preston Park Museum & Grounds\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"social\", \"precision\": \"estimate\", \"artefact_count\": 100000}, {\"institution\": \"Ripon Museums\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"social\", \"precision\": \"estimate\", \"artefact_count\": 9000}, {\"institution\": \"Royal Albert Memorial Museum\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 1000000}, {\"institution\": \"Salisbury Museum\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 100000}, {\"institution\": \"St Helens Borough Council\", \"sector\": \"regional\", \"type\": \"archive\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 0}, {\"institution\": \"Sunderland Museum & Winter Gardens' Collection\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 108000}, {\"institution\": \"Wakefield Museums and Castles Collections\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 111000}, {\"institution\": \"Weald and Downland Living Museum\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 15000}, {\"institution\": \"York Museums Trust\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 0}, {\"institution\": \"Victoria & Albert Museum\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"art\", \"precision\": \"estimate\", \"artefact_count\": 2800000}, {\"institution\": \"Science Museum Group\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"science\", \"precision\": \"estimate\", \"artefact_count\": 7360793}, {\"institution\": \"Museum of the Home\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"history\", \"precision\": \"estimate\", \"artefact_count\": 40000}, {\"institution\": \"Horniman Museum\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"history\", \"precision\": \"estimate\", \"artefact_count\": 350000}, {\"institution\": \"Imperial War Museums\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"history\", \"precision\": \"estimate\", \"artefact_count\": 1000000}, {\"institution\": \"National Gallery\", \"sector\": \"dcms\", \"type\": \"gallery\", \"topic\": \"art\", \"precision\": \"estimate\", \"artefact_count\": 2626}, {\"institution\": \"National Museums Liverpool\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"history\", \"precision\": \"estimate\", \"artefact_count\": 4000000}, {\"institution\": \"National Portrait Gallery\", \"sector\": \"dcms\", \"type\": \"gallery\", \"topic\": \"art\", \"precision\": \"estimate\", \"artefact_count\": 350000}, {\"institution\": \"Royal Armouries\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"history\", \"precision\": \"estimate\", \"artefact_count\": 70000}, {\"institution\": \"Royal Museums Greenwich\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"history\", \"precision\": \"estimate\", \"artefact_count\": 3000000}, {\"institution\": \"Sir John Soane's Museum\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"history\", \"precision\": \"estimate\", \"artefact_count\": 52000}, {\"institution\": \"Tate Gallery Group\", \"sector\": \"dcms\", \"type\": \"gallery\", \"topic\": \"art\", \"precision\": \"estimate\", \"artefact_count\": 70000}, {\"institution\": \"The Wallace Collection\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"art\", \"precision\": \"estimate\", \"artefact_count\": 5637}, {\"institution\": \"British Museum\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"history\", \"precision\": \"estimate\", \"artefact_count\": 8000000}]}}, {\"mode\": \"vega-lite\"});\n",
       "</script>"
      ],
      "text/plain": [
       "alt.Chart(...)"
      ]
     },
     "execution_count": 89,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "title = alt.TitleParams('Artefacts by sector', anchor='middle')\n",
    "alt.Chart(artefacts_df,title=title).mark_bar().encode(\n",
    "    alt.Color('institution:N', legend=alt.Legend(orient='bottom',columns=4)),\n",
    "    x='artefact_count:Q',\n",
    "    tooltip=['institution', 'artefact_count'],\n",
    "    y='topic:N',\n",
    "    column='sector'\n",
    ").properties(width=225).resolve_scale(x='independent').configure(numberFormat='.2s')\n",
    "\n",
    "# Uncertainty of level 2 - would fall if any institution was certain abnout artefacts (by 1/num_institutions)"
   ]
  },
  {
   "cell_type": "markdown",
   "id": "0b2524e5-d258-4141-b761-e85e51514797",
   "metadata": {
    "editable": true,
    "slideshow": {
     "slide_type": ""
    },
    "tags": []
   },
   "source": [
    "## Artefacts by sector (excluding specimen collections)\n",
    "\n",
    "Showing the distribution of artefacts (a cultural heritage item of any type)\n",
    "on different topic held in each sector, excluding nature collections."
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 90,
   "id": "9ec54dca-91c8-4be3-822f-df5476192ff7",
   "metadata": {
    "editable": true,
    "slideshow": {
     "slide_type": ""
    },
    "tags": [
     "remove-input",
     "full-size"
    ]
   },
   "outputs": [
    {
     "data": {
      "text/html": [
       "\n",
       "<style>\n",
       "  #altair-viz-3f32e08692774713a1d110003769fc18.vega-embed {\n",
       "    width: 100%;\n",
       "    display: flex;\n",
       "  }\n",
       "\n",
       "  #altair-viz-3f32e08692774713a1d110003769fc18.vega-embed details,\n",
       "  #altair-viz-3f32e08692774713a1d110003769fc18.vega-embed details summary {\n",
       "    position: relative;\n",
       "  }\n",
       "</style>\n",
       "<div id=\"altair-viz-3f32e08692774713a1d110003769fc18\"></div>\n",
       "<script type=\"text/javascript\">\n",
       "  var VEGA_DEBUG = (typeof VEGA_DEBUG == \"undefined\") ? {} : VEGA_DEBUG;\n",
       "  (function(spec, embedOpt){\n",
       "    let outputDiv = document.currentScript.previousElementSibling;\n",
       "    if (outputDiv.id !== \"altair-viz-3f32e08692774713a1d110003769fc18\") {\n",
       "      outputDiv = document.getElementById(\"altair-viz-3f32e08692774713a1d110003769fc18\");\n",
       "    }\n",
       "    const paths = {\n",
       "      \"vega\": \"https://cdn.jsdelivr.net/npm/vega@5?noext\",\n",
       "      \"vega-lib\": \"https://cdn.jsdelivr.net/npm/vega-lib?noext\",\n",
       "      \"vega-lite\": \"https://cdn.jsdelivr.net/npm/vega-lite@5.17.0?noext\",\n",
       "      \"vega-embed\": \"https://cdn.jsdelivr.net/npm/vega-embed@6?noext\",\n",
       "    };\n",
       "\n",
       "    function maybeLoadScript(lib, version) {\n",
       "      var key = `${lib.replace(\"-\", \"\")}_version`;\n",
       "      return (VEGA_DEBUG[key] == version) ?\n",
       "        Promise.resolve(paths[lib]) :\n",
       "        new Promise(function(resolve, reject) {\n",
       "          var s = document.createElement('script');\n",
       "          document.getElementsByTagName(\"head\")[0].appendChild(s);\n",
       "          s.async = true;\n",
       "          s.onload = () => {\n",
       "            VEGA_DEBUG[key] = version;\n",
       "            return resolve(paths[lib]);\n",
       "          };\n",
       "          s.onerror = () => reject(`Error loading script: ${paths[lib]}`);\n",
       "          s.src = paths[lib];\n",
       "        });\n",
       "    }\n",
       "\n",
       "    function showError(err) {\n",
       "      outputDiv.innerHTML = `<div class=\"error\" style=\"color:red;\">${err}</div>`;\n",
       "      throw err;\n",
       "    }\n",
       "\n",
       "    function displayChart(vegaEmbed) {\n",
       "      vegaEmbed(outputDiv, spec, embedOpt)\n",
       "        .catch(err => showError(`Javascript Error: ${err.message}<br>This usually means there's a typo in your chart specification. See the javascript console for the full traceback.`));\n",
       "    }\n",
       "\n",
       "    if(typeof define === \"function\" && define.amd) {\n",
       "      requirejs.config({paths});\n",
       "      require([\"vega-embed\"], displayChart, err => showError(`Error loading script: ${err.message}`));\n",
       "    } else {\n",
       "      maybeLoadScript(\"vega\", \"5\")\n",
       "        .then(() => maybeLoadScript(\"vega-lite\", \"5.17.0\"))\n",
       "        .then(() => maybeLoadScript(\"vega-embed\", \"6\"))\n",
       "        .catch(showError)\n",
       "        .then(() => displayChart(vegaEmbed));\n",
       "    }\n",
       "  })({\"config\": {\"view\": {\"continuousWidth\": 300, \"continuousHeight\": 300}, \"numberFormat\": \".2s\"}, \"data\": {\"name\": \"data-3e149954c15954462dde6b5ff93616c8\"}, \"mark\": {\"type\": \"bar\"}, \"encoding\": {\"color\": {\"field\": \"institution\", \"legend\": {\"columns\": 4, \"orient\": \"bottom\"}, \"type\": \"nominal\"}, \"column\": {\"field\": \"sector\", \"type\": \"nominal\"}, \"tooltip\": [{\"field\": \"institution\", \"type\": \"nominal\"}, {\"field\": \"artefact_count\", \"type\": \"quantitative\"}], \"x\": {\"field\": \"artefact_count\", \"type\": \"quantitative\"}, \"y\": {\"field\": \"topic\", \"type\": \"nominal\"}}, \"resolve\": {\"scale\": {\"x\": \"independent\"}}, \"title\": {\"text\": \"Collection Size (Artefacts) by sector (without Nature collections)\", \"anchor\": \"middle\"}, \"width\": 225, \"$schema\": \"https://vega.github.io/schema/vega-lite/v5.17.0.json\", \"datasets\": {\"data-3e149954c15954462dde6b5ff93616c8\": [{\"institution\": \"Oxford University\", \"sector\": \"university\", \"type\": \"university\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 22530000}, {\"institution\": \"University of Cambridge\", \"sector\": \"university\", \"type\": \"university\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 4007000}, {\"institution\": \"Durham University\", \"sector\": \"university\", \"type\": \"university\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 106000}, {\"institution\": \"University College London\", \"sector\": \"university\", \"type\": \"university\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 164000}, {\"institution\": \"University of Manchester\", \"sector\": \"university\", \"type\": \"university\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 8560000}, {\"institution\": \"King's College London\", \"sector\": \"university\", \"type\": \"university\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 200000}, {\"institution\": \"University of Birmingham\", \"sector\": \"university\", \"type\": \"university\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 4500000}, {\"institution\": \"Unversity of Warwick\", \"sector\": \"university\", \"type\": \"university\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 16000}, {\"institution\": \"Manchester Metropolitan Unversity\", \"sector\": \"university\", \"type\": \"university\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 0}, {\"institution\": \"Swansea University\", \"sector\": \"university\", \"type\": \"university\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 1700}, {\"institution\": \"University of Brighton\", \"sector\": \"university\", \"type\": \"university\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 50000}, {\"institution\": \"SOAS, University of London\", \"sector\": \"university\", \"type\": \"university\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 60000}, {\"institution\": \"University of Aberdeen\", \"sector\": \"university\", \"type\": \"university\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 530000}, {\"institution\": \"University of Bristol\", \"sector\": \"university\", \"type\": \"university\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 100000}, {\"institution\": \"University of Leeds\", \"sector\": \"university\", \"type\": \"university\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 350000}, {\"institution\": \"University of Sheffield\", \"sector\": \"university\", \"type\": \"university\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 30000}, {\"institution\": \"University of St Andrews\", \"sector\": \"university\", \"type\": \"university\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 200000}, {\"institution\": \"Royal College of Surgeons\", \"sector\": \"university\", \"type\": \"university\", \"topic\": \"medicine\", \"precision\": \"estimate\", \"artefact_count\": 3500}, {\"institution\": \"British Library\", \"sector\": \"library\", \"type\": \"library\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 45810000}, {\"institution\": \"Chetham's Library\", \"sector\": \"library\", \"type\": \"library\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 121041}, {\"institution\": \"Glasgow Woman's Library\", \"sector\": \"library\", \"type\": \"library\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 0}, {\"institution\": \"Lambeth Palace Library\", \"sector\": \"library\", \"type\": \"library\", \"topic\": \"theology\", \"precision\": \"estimate\", \"artefact_count\": 186200}, {\"institution\": \"National Library of Wales\", \"sector\": \"library\", \"type\": \"library\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 7540000}, {\"institution\": \"National Library of Scotland\", \"sector\": \"library\", \"type\": \"library\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 37000000}, {\"institution\": \"Amgueddfa Cymru (National Museum Wales)\", \"sector\": \"national\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 5319585}, {\"institution\": \"Historic Royal Palaces\", \"sector\": \"national\", \"type\": \"building\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 60000}, {\"institution\": \"National Football Museum\", \"sector\": \"national\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 40000}, {\"institution\": \"National Justice Museum\", \"sector\": \"national\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 40000}, {\"institution\": \"National Mining Museum Scotland\", \"sector\": \"national\", \"type\": \"museum\", \"topic\": \"industry\", \"precision\": \"estimate\", \"artefact_count\": 100000}, {\"institution\": \"National Museum of the Royal Navy\", \"sector\": \"national\", \"type\": \"museum\", \"topic\": \"maritime\", \"precision\": \"estimate\", \"artefact_count\": 2500000}, {\"institution\": \"National Museums NI\", \"sector\": \"national\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 1400000}, {\"institution\": \"National Museums Scotland\", \"sector\": \"national\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 12000000}, {\"institution\": \"National Tramway Museum\", \"sector\": \"national\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 46690}, {\"institution\": \"National Trust\", \"sector\": \"national\", \"type\": \"building\", \"topic\": \"art\", \"precision\": \"estimate\", \"artefact_count\": 1000000}, {\"institution\": \"National Trust for Scotland\", \"sector\": \"national\", \"type\": \"building\", \"topic\": \"art\", \"precision\": \"estimate\", \"artefact_count\": 300000}, {\"institution\": \"National Waterways Museum\", \"sector\": \"national\", \"type\": \"building\", \"topic\": \"transport\", \"precision\": \"estimate\", \"artefact_count\": 150000}, {\"institution\": \"Government Art Collection\", \"sector\": \"national\", \"type\": \"museum\", \"topic\": \"art\", \"precision\": \"estimate\", \"artefact_count\": 15000}, {\"institution\": \"Historic Environment Scotland\", \"sector\": \"national\", \"type\": \"museum\", \"topic\": \"heritage\", \"precision\": \"estimate\", \"artefact_count\": 41000}, {\"institution\": \"People's History Museum\", \"sector\": \"national\", \"type\": \"museum\", \"topic\": \"social\", \"precision\": \"estimate\", \"artefact_count\": 5680}, {\"institution\": \"Portable Antiquities Scheme\", \"sector\": \"national\", \"type\": \"museum\", \"topic\": \"archaeology\", \"precision\": \"estimate\", \"artefact_count\": 1751232}, {\"institution\": \"Royal Air Force Museum\", \"sector\": \"national\", \"type\": \"museum\", \"topic\": \"military\", \"precision\": \"estimate\", \"artefact_count\": 1300000}, {\"institution\": \"Royal Collection\", \"sector\": \"national\", \"type\": \"museum\", \"topic\": \"art\", \"precision\": \"estimate\", \"artefact_count\": 1000000}, {\"institution\": \"Staffordshire Archive and Heritage\", \"sector\": \"regional\", \"type\": \"mixed\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 0}, {\"institution\": \"Courtauld Gallery\", \"sector\": \"independent\", \"type\": \"gallery\", \"topic\": \"art\", \"precision\": \"estimate\", \"artefact_count\": 33501}, {\"institution\": \"Dulwich Picture Gallery\", \"sector\": \"independent\", \"type\": \"gallery\", \"topic\": \"art\", \"precision\": \"estimate\", \"artefact_count\": 600}, {\"institution\": \"Manchester Art Gallery\", \"sector\": \"independent\", \"type\": \"gallery\", \"topic\": \"art\", \"precision\": \"estimate\", \"artefact_count\": 46000}, {\"institution\": \"National Galleries Scotland\", \"sector\": \"independent\", \"type\": \"gallery\", \"topic\": \"art\", \"precision\": \"estimate\", \"artefact_count\": 120000}, {\"institution\": \"William Morris Gallery\", \"sector\": \"regional\", \"type\": \"gallery\", \"topic\": \"art\", \"precision\": \"estimate\", \"artefact_count\": 10000}, {\"institution\": \"Bowes Museum\", \"sector\": \"independent\", \"type\": \"museum\", \"topic\": \"art\", \"precision\": \"estimate\", \"artefact_count\": 30000}, {\"institution\": \"Britten Pears\", \"sector\": \"independent\", \"type\": \"museum\", \"topic\": \"art\", \"precision\": \"estimate\", \"artefact_count\": 1200}, {\"institution\": \"Chatham Historic Dockyard\", \"sector\": \"independent\", \"type\": \"building\", \"topic\": \"maritime\", \"precision\": \"estimate\", \"artefact_count\": 70000}, {\"institution\": \"English Heritage Trust\", \"sector\": \"independent\", \"type\": \"building\", \"topic\": \"history\", \"precision\": \"estimate\", \"artefact_count\": 700000}, {\"institution\": \"Gordon Highlanders Museum\", \"sector\": \"independent\", \"type\": \"museum\", \"topic\": \"military\", \"precision\": \"estimate\", \"artefact_count\": 40000}, {\"institution\": \"Ironbridge Gorge Museum Trust\", \"sector\": \"independent\", \"type\": \"museum\", \"topic\": \"industry\", \"precision\": \"estimate\", \"artefact_count\": 400000}, {\"institution\": \"Jewish Museum London\", \"sector\": \"independent\", \"type\": \"museum\", \"topic\": \"social\", \"precision\": \"estimate\", \"artefact_count\": 40000}, {\"institution\": \"London Transport Museum\", \"sector\": \"independent\", \"type\": \"museum\", \"topic\": \"transport\", \"precision\": \"estimate\", \"artefact_count\": 500000}, {\"institution\": \"Manchester Jewish Museum\", \"sector\": \"independent\", \"type\": \"museum\", \"topic\": \"social\", \"precision\": \"estimate\", \"artefact_count\": 31000}, {\"institution\": \"Mary Rose Trust\", \"sector\": \"independent\", \"type\": \"museum\", \"topic\": \"maritime\", \"precision\": \"estimate\", \"artefact_count\": 19000}, {\"institution\": \"Media Archive for Central England (MACE)\", \"sector\": \"independent\", \"type\": \"archive\", \"topic\": \"media\", \"precision\": \"estimate\", \"artefact_count\": 65000}, {\"institution\": \"Food Museum\", \"sector\": \"independent\", \"type\": \"museum\", \"topic\": \"social\", \"precision\": \"estimate\", \"artefact_count\": 40000}, {\"institution\": \"Museum of Freemasonry\", \"sector\": \"independent\", \"type\": \"museum\", \"topic\": \"social\", \"precision\": \"estimate\", \"artefact_count\": 90000}, {\"institution\": \"Museum of Lead Mining\", \"sector\": \"independent\", \"type\": \"museum\", \"topic\": \"industry\", \"precision\": \"estimate\", \"artefact_count\": 2572}, {\"institution\": \"Museum of Scottish Railways\", \"sector\": \"independent\", \"type\": \"museum\", \"topic\": \"industry\", \"precision\": \"estimate\", \"artefact_count\": 50000}, {\"institution\": \"Paxton Trust\", \"sector\": \"independent\", \"type\": \"building\", \"topic\": \"art\", \"precision\": \"estimate\", \"artefact_count\": 3754}, {\"institution\": \"Pier Arts Centre\", \"sector\": \"independent\", \"type\": \"gallery\", \"topic\": \"art\", \"precision\": \"estimate\", \"artefact_count\": 180}, {\"institution\": \"Postal Museum\", \"sector\": \"independent\", \"type\": \"museum\", \"topic\": \"social\", \"precision\": \"estimate\", \"artefact_count\": 60000}, {\"institution\": \"Royal Artillery Museum\", \"sector\": \"independent\", \"type\": \"museum\", \"topic\": \"military\", \"precision\": \"estimate\", \"artefact_count\": 30000}, {\"institution\": \"Royal Engineers Museum\", \"sector\": \"independent\", \"type\": \"museum\", \"topic\": \"military\", \"precision\": \"estimate\", \"artefact_count\": 1000000}, {\"institution\": \"Royal Scottish Academy of Art & Architecture\", \"sector\": \"independent\", \"type\": \"museum\", \"topic\": \"art\", \"precision\": \"estimate\", \"artefact_count\": 9000}, {\"institution\": \"Scottish Fisheries Museum\", \"sector\": \"independent\", \"type\": \"museum\", \"topic\": \"maritime\", \"precision\": \"estimate\", \"artefact_count\": 66000}, {\"institution\": \"Thackray Museum of Medicine\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"medicine\", \"precision\": \"estimate\", \"artefact_count\": 75000}, {\"institution\": \"Tuillie House Museum and Art Gallery\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 1000000}, {\"institution\": \"Wellcome Collection\", \"sector\": \"independent\", \"type\": \"museum\", \"topic\": \"medicine\", \"precision\": \"estimate\", \"artefact_count\": 2250000}, {\"institution\": \"Wordsworth Museum Collection\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"literature\", \"precision\": \"estimate\", \"artefact_count\": 68000}, {\"institution\": \"Aberdeenshire Council Museums\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 250000}, {\"institution\": \"Barnsley Museums\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 711400}, {\"institution\": \"Birmingham Museums Trust\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"art\", \"precision\": \"estimate\", \"artefact_count\": 800000}, {\"institution\": \"Black Country Living Museum\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"history\", \"precision\": \"estimate\", \"artefact_count\": 80000}, {\"institution\": \"Bradford District Museums & Galleries\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 837837}, {\"institution\": \"Bristol Museums\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 2000000}, {\"institution\": \"Culture Coventry\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 1000000}, {\"institution\": \"Culture Perth and Kinross\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 500000}, {\"institution\": \"Culture Trust Luton\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 1105051}, {\"institution\": \"Dundee Heritage Trust\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 0}, {\"institution\": \"Elgin Museum\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 36000}, {\"institution\": \"Glasgow Museums\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 1000000}, {\"institution\": \"Heritage Doncaster\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 406750}, {\"institution\": \"Highland Folk Museum\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"social\", \"precision\": \"estimate\", \"artefact_count\": 10000}, {\"institution\": \"Leeds Museums & Galleries\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 1300000}, {\"institution\": \"Leicester Museums\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 1500000}, {\"institution\": \"Manchester Art Gallery\", \"sector\": \"regional\", \"type\": \"gallery\", \"topic\": \"art\", \"precision\": \"estimate\", \"artefact_count\": 50000}, {\"institution\": \"Edinburgh Museums\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 220000}, {\"institution\": \"Museums Northumberland\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 25000}, {\"institution\": \"Northampton Museums\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 44024}, {\"institution\": \"Orkney Museums\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 100000}, {\"institution\": \"Poole Museums\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 50000}, {\"institution\": \"Potteries Museum and Art Gallery\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"art\", \"precision\": \"estimate\", \"artefact_count\": 1000000}, {\"institution\": \"Preston Park Museum & Grounds\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"social\", \"precision\": \"estimate\", \"artefact_count\": 100000}, {\"institution\": \"Ripon Museums\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"social\", \"precision\": \"estimate\", \"artefact_count\": 9000}, {\"institution\": \"Royal Albert Memorial Museum\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 1000000}, {\"institution\": \"Salisbury Museum\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 100000}, {\"institution\": \"St Helens Borough Council\", \"sector\": \"regional\", \"type\": \"archive\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 0}, {\"institution\": \"Sunderland Museum & Winter Gardens' Collection\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 108000}, {\"institution\": \"Wakefield Museums and Castles Collections\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 111000}, {\"institution\": \"Weald and Downland Living Museum\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 15000}, {\"institution\": \"York Museums Trust\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 0}, {\"institution\": \"Victoria & Albert Museum\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"art\", \"precision\": \"estimate\", \"artefact_count\": 2800000}, {\"institution\": \"Science Museum Group\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"science\", \"precision\": \"estimate\", \"artefact_count\": 7360793}, {\"institution\": \"Museum of the Home\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"history\", \"precision\": \"estimate\", \"artefact_count\": 40000}, {\"institution\": \"Horniman Museum\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"history\", \"precision\": \"estimate\", \"artefact_count\": 350000}, {\"institution\": \"Imperial War Museums\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"history\", \"precision\": \"estimate\", \"artefact_count\": 1000000}, {\"institution\": \"National Gallery\", \"sector\": \"dcms\", \"type\": \"gallery\", \"topic\": \"art\", \"precision\": \"estimate\", \"artefact_count\": 2626}, {\"institution\": \"National Museums Liverpool\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"history\", \"precision\": \"estimate\", \"artefact_count\": 4000000}, {\"institution\": \"National Portrait Gallery\", \"sector\": \"dcms\", \"type\": \"gallery\", \"topic\": \"art\", \"precision\": \"estimate\", \"artefact_count\": 350000}, {\"institution\": \"Royal Armouries\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"history\", \"precision\": \"estimate\", \"artefact_count\": 70000}, {\"institution\": \"Royal Museums Greenwich\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"history\", \"precision\": \"estimate\", \"artefact_count\": 3000000}, {\"institution\": \"Sir John Soane's Museum\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"history\", \"precision\": \"estimate\", \"artefact_count\": 52000}, {\"institution\": \"Tate Gallery Group\", \"sector\": \"dcms\", \"type\": \"gallery\", \"topic\": \"art\", \"precision\": \"estimate\", \"artefact_count\": 70000}, {\"institution\": \"The Wallace Collection\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"art\", \"precision\": \"estimate\", \"artefact_count\": 5637}, {\"institution\": \"British Museum\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"history\", \"precision\": \"estimate\", \"artefact_count\": 8000000}]}}, {\"mode\": \"vega-lite\"});\n",
       "</script>"
      ],
      "text/plain": [
       "alt.Chart(...)"
      ]
     },
     "execution_count": 90,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "title = alt.TitleParams('Collection Size (Artefacts) by topic and sector (without Nature collections)', anchor='middle')\n",
    "alt.Chart(artefacts_non_nature_df,title=title).mark_bar().encode(\n",
    "    alt.Color('institution:N', legend=alt.Legend(orient='bottom',columns=4)),\n",
    "    x='artefact_count:Q',\n",
    "    tooltip=['institution', 'artefact_count'],\n",
    "    y='topic:N',\n",
    "    column='sector'\n",
    ").properties(width=225).resolve_scale(x='independent').configure(numberFormat='.2s')\n",
    "\n",
    "# Uncertainty of level 2 - would fall if any institution was certain abnout artefacts (by 1/num_institutions)"
   ]
  },
  {
   "cell_type": "markdown",
   "id": "25862f92-fd57-4d87-90b9-613cc5754280",
   "metadata": {
    "editable": true,
    "slideshow": {
     "slide_type": ""
    },
    "tags": []
   },
   "source": [
    "## Artefacts by institution type"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 98,
   "id": "4f2a7ca6-7a3a-4176-bf8b-b22250451b61",
   "metadata": {
    "editable": true,
    "slideshow": {
     "slide_type": ""
    },
    "tags": [
     "remove-input",
     "full-size"
    ]
   },
   "outputs": [
    {
     "data": {
      "text/html": [
       "\n",
       "<style>\n",
       "  #altair-viz-c6ee7dcb4f464022b56df395b96e6b2b.vega-embed {\n",
       "    width: 100%;\n",
       "    display: flex;\n",
       "  }\n",
       "\n",
       "  #altair-viz-c6ee7dcb4f464022b56df395b96e6b2b.vega-embed details,\n",
       "  #altair-viz-c6ee7dcb4f464022b56df395b96e6b2b.vega-embed details summary {\n",
       "    position: relative;\n",
       "  }\n",
       "</style>\n",
       "<div id=\"altair-viz-c6ee7dcb4f464022b56df395b96e6b2b\"></div>\n",
       "<script type=\"text/javascript\">\n",
       "  var VEGA_DEBUG = (typeof VEGA_DEBUG == \"undefined\") ? {} : VEGA_DEBUG;\n",
       "  (function(spec, embedOpt){\n",
       "    let outputDiv = document.currentScript.previousElementSibling;\n",
       "    if (outputDiv.id !== \"altair-viz-c6ee7dcb4f464022b56df395b96e6b2b\") {\n",
       "      outputDiv = document.getElementById(\"altair-viz-c6ee7dcb4f464022b56df395b96e6b2b\");\n",
       "    }\n",
       "    const paths = {\n",
       "      \"vega\": \"https://cdn.jsdelivr.net/npm/vega@5?noext\",\n",
       "      \"vega-lib\": \"https://cdn.jsdelivr.net/npm/vega-lib?noext\",\n",
       "      \"vega-lite\": \"https://cdn.jsdelivr.net/npm/vega-lite@5.17.0?noext\",\n",
       "      \"vega-embed\": \"https://cdn.jsdelivr.net/npm/vega-embed@6?noext\",\n",
       "    };\n",
       "\n",
       "    function maybeLoadScript(lib, version) {\n",
       "      var key = `${lib.replace(\"-\", \"\")}_version`;\n",
       "      return (VEGA_DEBUG[key] == version) ?\n",
       "        Promise.resolve(paths[lib]) :\n",
       "        new Promise(function(resolve, reject) {\n",
       "          var s = document.createElement('script');\n",
       "          document.getElementsByTagName(\"head\")[0].appendChild(s);\n",
       "          s.async = true;\n",
       "          s.onload = () => {\n",
       "            VEGA_DEBUG[key] = version;\n",
       "            return resolve(paths[lib]);\n",
       "          };\n",
       "          s.onerror = () => reject(`Error loading script: ${paths[lib]}`);\n",
       "          s.src = paths[lib];\n",
       "        });\n",
       "    }\n",
       "\n",
       "    function showError(err) {\n",
       "      outputDiv.innerHTML = `<div class=\"error\" style=\"color:red;\">${err}</div>`;\n",
       "      throw err;\n",
       "    }\n",
       "\n",
       "    function displayChart(vegaEmbed) {\n",
       "      vegaEmbed(outputDiv, spec, embedOpt)\n",
       "        .catch(err => showError(`Javascript Error: ${err.message}<br>This usually means there's a typo in your chart specification. See the javascript console for the full traceback.`));\n",
       "    }\n",
       "\n",
       "    if(typeof define === \"function\" && define.amd) {\n",
       "      requirejs.config({paths});\n",
       "      require([\"vega-embed\"], displayChart, err => showError(`Error loading script: ${err.message}`));\n",
       "    } else {\n",
       "      maybeLoadScript(\"vega\", \"5\")\n",
       "        .then(() => maybeLoadScript(\"vega-lite\", \"5.17.0\"))\n",
       "        .then(() => maybeLoadScript(\"vega-embed\", \"6\"))\n",
       "        .catch(showError)\n",
       "        .then(() => displayChart(vegaEmbed));\n",
       "    }\n",
       "  })({\"config\": {\"view\": {\"continuousWidth\": 300, \"continuousHeight\": 300}, \"numberFormat\": \".2s\"}, \"data\": {\"name\": \"data-289f10ddddf01ded7844889c2d33adee\"}, \"mark\": {\"type\": \"bar\"}, \"encoding\": {\"color\": {\"field\": \"institution\", \"legend\": {\"columns\": 4, \"orient\": \"bottom\", \"symbolLimit\": 80}, \"sort\": \"descending\", \"type\": \"nominal\"}, \"column\": {\"field\": \"precision\", \"type\": \"ordinal\"}, \"tooltip\": [{\"field\": \"institution\", \"type\": \"nominal\"}, {\"field\": \"artefact_count\", \"type\": \"quantitative\"}], \"x\": {\"field\": \"artefact_count\", \"type\": \"quantitative\"}, \"y\": {\"field\": \"type\", \"type\": \"nominal\"}}, \"resolve\": {\"scale\": {\"x\": \"independent\"}}, \"title\": {\"text\": \"Artefacts by institution type\", \"anchor\": \"middle\"}, \"width\": 900, \"$schema\": \"https://vega.github.io/schema/vega-lite/v5.17.0.json\", \"datasets\": {\"data-289f10ddddf01ded7844889c2d33adee\": [{\"institution\": \"Oxford University\", \"sector\": \"university\", \"type\": \"university\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 22530000}, {\"institution\": \"University of Cambridge\", \"sector\": \"university\", \"type\": \"university\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 4007000}, {\"institution\": \"Durham University\", \"sector\": \"university\", \"type\": \"university\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 106000}, {\"institution\": \"University College London\", \"sector\": \"university\", \"type\": \"university\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 164000}, {\"institution\": \"University of Manchester\", \"sector\": \"university\", \"type\": \"university\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 8560000}, {\"institution\": \"King's College London\", \"sector\": \"university\", \"type\": \"university\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 200000}, {\"institution\": \"University of Birmingham\", \"sector\": \"university\", \"type\": \"university\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 4500000}, {\"institution\": \"Unversity of Warwick\", \"sector\": \"university\", \"type\": \"university\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 16000}, {\"institution\": \"Manchester Metropolitan Unversity\", \"sector\": \"university\", \"type\": \"university\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 0}, {\"institution\": \"Swansea University\", \"sector\": \"university\", \"type\": \"university\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 1700}, {\"institution\": \"University of Brighton\", \"sector\": \"university\", \"type\": \"university\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 50000}, {\"institution\": \"SOAS, University of London\", \"sector\": \"university\", \"type\": \"university\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 60000}, {\"institution\": \"University of Aberdeen\", \"sector\": \"university\", \"type\": \"university\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 530000}, {\"institution\": \"University of Bristol\", \"sector\": \"university\", \"type\": \"university\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 100000}, {\"institution\": \"University of Leeds\", \"sector\": \"university\", \"type\": \"university\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 350000}, {\"institution\": \"University of Sheffield\", \"sector\": \"university\", \"type\": \"university\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 30000}, {\"institution\": \"University of St Andrews\", \"sector\": \"university\", \"type\": \"university\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 200000}, {\"institution\": \"Royal College of Surgeons\", \"sector\": \"university\", \"type\": \"university\", \"topic\": \"medicine\", \"precision\": \"estimate\", \"artefact_count\": 3500}, {\"institution\": \"British Library\", \"sector\": \"library\", \"type\": \"library\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 45810000}, {\"institution\": \"Chetham's Library\", \"sector\": \"library\", \"type\": \"library\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 121041}, {\"institution\": \"Glasgow Woman's Library\", \"sector\": \"library\", \"type\": \"library\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 0}, {\"institution\": \"Lambeth Palace Library\", \"sector\": \"library\", \"type\": \"library\", \"topic\": \"theology\", \"precision\": \"estimate\", \"artefact_count\": 186200}, {\"institution\": \"National Library of Wales\", \"sector\": \"library\", \"type\": \"library\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 7540000}, {\"institution\": \"National Library of Scotland\", \"sector\": \"library\", \"type\": \"library\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 37000000}, {\"institution\": \"Amgueddfa Cymru (National Museum Wales)\", \"sector\": \"national\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 5319585}, {\"institution\": \"Historic Royal Palaces\", \"sector\": \"national\", \"type\": \"building\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 60000}, {\"institution\": \"National Football Museum\", \"sector\": \"national\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 40000}, {\"institution\": \"National Justice Museum\", \"sector\": \"national\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 40000}, {\"institution\": \"National Mining Museum Scotland\", \"sector\": \"national\", \"type\": \"museum\", \"topic\": \"industry\", \"precision\": \"estimate\", \"artefact_count\": 100000}, {\"institution\": \"National Museum of the Royal Navy\", \"sector\": \"national\", \"type\": \"museum\", \"topic\": \"maritime\", \"precision\": \"estimate\", \"artefact_count\": 2500000}, {\"institution\": \"National Museums NI\", \"sector\": \"national\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 1400000}, {\"institution\": \"National Museums Scotland\", \"sector\": \"national\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 12000000}, {\"institution\": \"National Tramway Museum\", \"sector\": \"national\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 46690}, {\"institution\": \"National Trust\", \"sector\": \"national\", \"type\": \"building\", \"topic\": \"heritage\", \"precision\": \"estimate\", \"artefact_count\": 1000000}, {\"institution\": \"National Trust for Scotland\", \"sector\": \"national\", \"type\": \"building\", \"topic\": \"heritage\", \"precision\": \"estimate\", \"artefact_count\": 300000}, {\"institution\": \"National Waterways Museum\", \"sector\": \"national\", \"type\": \"building\", \"topic\": \"transport\", \"precision\": \"estimate\", \"artefact_count\": 150000}, {\"institution\": \"Government Art Collection\", \"sector\": \"national\", \"type\": \"museum\", \"topic\": \"art\", \"precision\": \"estimate\", \"artefact_count\": 15000}, {\"institution\": \"Historic Environment Scotland\", \"sector\": \"national\", \"type\": \"museum\", \"topic\": \"heritage\", \"precision\": \"estimate\", \"artefact_count\": 41000}, {\"institution\": \"People's History Museum\", \"sector\": \"national\", \"type\": \"museum\", \"topic\": \"social\", \"precision\": \"estimate\", \"artefact_count\": 5680}, {\"institution\": \"Portable Antiquities Scheme\", \"sector\": \"national\", \"type\": \"museum\", \"topic\": \"archaeology\", \"precision\": \"estimate\", \"artefact_count\": 1751232}, {\"institution\": \"Royal Air Force Museum\", \"sector\": \"national\", \"type\": \"museum\", \"topic\": \"military\", \"precision\": \"estimate\", \"artefact_count\": 1300000}, {\"institution\": \"Royal Botanic Gardens Kew\", \"sector\": \"national\", \"type\": \"museum\", \"topic\": \"nature\", \"precision\": \"estimate\", \"artefact_count\": 7000000}, {\"institution\": \"Royal Collection\", \"sector\": \"national\", \"type\": \"museum\", \"topic\": \"art\", \"precision\": \"estimate\", \"artefact_count\": 1000000}, {\"institution\": \"Staffordshire Archive and Heritage\", \"sector\": \"regional\", \"type\": \"mixed\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 0}, {\"institution\": \"Courtauld Gallery\", \"sector\": \"independent\", \"type\": \"gallery\", \"topic\": \"art\", \"precision\": \"estimate\", \"artefact_count\": 33501}, {\"institution\": \"Dulwich Picture Gallery\", \"sector\": \"independent\", \"type\": \"gallery\", \"topic\": \"art\", \"precision\": \"estimate\", \"artefact_count\": 600}, {\"institution\": \"Manchester Art Gallery\", \"sector\": \"independent\", \"type\": \"gallery\", \"topic\": \"art\", \"precision\": \"estimate\", \"artefact_count\": 46000}, {\"institution\": \"National Galleries Scotland\", \"sector\": \"independent\", \"type\": \"gallery\", \"topic\": \"art\", \"precision\": \"estimate\", \"artefact_count\": 120000}, {\"institution\": \"William Morris Gallery\", \"sector\": \"regional\", \"type\": \"gallery\", \"topic\": \"art\", \"precision\": \"estimate\", \"artefact_count\": 10000}, {\"institution\": \"Linnaean Society\", \"sector\": \"societies\", \"type\": \"museum\", \"topic\": \"nature\", \"precision\": \"estimate\", \"artefact_count\": 20268}, {\"institution\": \"Bowes Museum\", \"sector\": \"independent\", \"type\": \"museum\", \"topic\": \"art\", \"precision\": \"estimate\", \"artefact_count\": 30000}, {\"institution\": \"Britten Pears\", \"sector\": \"independent\", \"type\": \"museum\", \"topic\": \"art\", \"precision\": \"estimate\", \"artefact_count\": 1200}, {\"institution\": \"Chatham Historic Dockyard\", \"sector\": \"independent\", \"type\": \"building\", \"topic\": \"maritime\", \"precision\": \"estimate\", \"artefact_count\": 70000}, {\"institution\": \"English Heritage Trust\", \"sector\": \"independent\", \"type\": \"building\", \"topic\": \"heritage\", \"precision\": \"estimate\", \"artefact_count\": 700000}, {\"institution\": \"Gordon Highlanders Museum\", \"sector\": \"independent\", \"type\": \"museum\", \"topic\": \"military\", \"precision\": \"estimate\", \"artefact_count\": 40000}, {\"institution\": \"Ironbridge Gorge Museum Trust\", \"sector\": \"independent\", \"type\": \"museum\", \"topic\": \"industry\", \"precision\": \"estimate\", \"artefact_count\": 400000}, {\"institution\": \"Jewish Museum London\", \"sector\": \"independent\", \"type\": \"museum\", \"topic\": \"social\", \"precision\": \"estimate\", \"artefact_count\": 40000}, {\"institution\": \"London Transport Museum\", \"sector\": \"independent\", \"type\": \"museum\", \"topic\": \"transport\", \"precision\": \"estimate\", \"artefact_count\": 500000}, {\"institution\": \"Manchester Jewish Museum\", \"sector\": \"independent\", \"type\": \"museum\", \"topic\": \"social\", \"precision\": \"estimate\", \"artefact_count\": 31000}, {\"institution\": \"Mary Rose Trust\", \"sector\": \"independent\", \"type\": \"museum\", \"topic\": \"maritime\", \"precision\": \"estimate\", \"artefact_count\": 19000}, {\"institution\": \"Food Museum\", \"sector\": \"independent\", \"type\": \"museum\", \"topic\": \"social\", \"precision\": \"estimate\", \"artefact_count\": 40000}, {\"institution\": \"Museum of Freemasonry\", \"sector\": \"independent\", \"type\": \"museum\", \"topic\": \"social\", \"precision\": \"estimate\", \"artefact_count\": 90000}, {\"institution\": \"Museum of Lead Mining\", \"sector\": \"independent\", \"type\": \"museum\", \"topic\": \"industry\", \"precision\": \"estimate\", \"artefact_count\": 2572}, {\"institution\": \"Museum of Scottish Railways\", \"sector\": \"independent\", \"type\": \"museum\", \"topic\": \"industry\", \"precision\": \"estimate\", \"artefact_count\": 50000}, {\"institution\": \"Paxton Trust\", \"sector\": \"independent\", \"type\": \"building\", \"topic\": \"art\", \"precision\": \"estimate\", \"artefact_count\": 3754}, {\"institution\": \"Pier Arts Centre\", \"sector\": \"independent\", \"type\": \"gallery\", \"topic\": \"art\", \"precision\": \"estimate\", \"artefact_count\": 180}, {\"institution\": \"Postal Museum\", \"sector\": \"independent\", \"type\": \"museum\", \"topic\": \"social\", \"precision\": \"estimate\", \"artefact_count\": 60000}, {\"institution\": \"Royal Artillery Museum\", \"sector\": \"independent\", \"type\": \"museum\", \"topic\": \"military\", \"precision\": \"estimate\", \"artefact_count\": 30000}, {\"institution\": \"Royal Engineers Museum\", \"sector\": \"independent\", \"type\": \"museum\", \"topic\": \"military\", \"precision\": \"estimate\", \"artefact_count\": 1000000}, {\"institution\": \"Royal Scottish Academy of Art & Architecture\", \"sector\": \"independent\", \"type\": \"museum\", \"topic\": \"art\", \"precision\": \"estimate\", \"artefact_count\": 9000}, {\"institution\": \"Scottish Fisheries Museum\", \"sector\": \"independent\", \"type\": \"museum\", \"topic\": \"maritime\", \"precision\": \"estimate\", \"artefact_count\": 66000}, {\"institution\": \"Thackray Museum of Medicine\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"medicine\", \"precision\": \"estimate\", \"artefact_count\": 75000}, {\"institution\": \"Tuillie House Museum and Art Gallery\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 1000000}, {\"institution\": \"Wellcome Collection\", \"sector\": \"independent\", \"type\": \"museum\", \"topic\": \"medicine\", \"precision\": \"estimate\", \"artefact_count\": 2250000}, {\"institution\": \"Wordsworth Museum Collection\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"literature\", \"precision\": \"estimate\", \"artefact_count\": 68000}, {\"institution\": \"Aberdeenshire Council Museums\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 250000}, {\"institution\": \"Barnsley Museums\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 711400}, {\"institution\": \"Birmingham Museums Trust\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"art\", \"precision\": \"estimate\", \"artefact_count\": 800000}, {\"institution\": \"Black Country Living Museum\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"history\", \"precision\": \"estimate\", \"artefact_count\": 80000}, {\"institution\": \"Bradford District Museums & Galleries\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 837837}, {\"institution\": \"Bristol Museums\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 2000000}, {\"institution\": \"Culture Coventry\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 1000000}, {\"institution\": \"Culture Perth and Kinross\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 500000}, {\"institution\": \"Culture Trust Luton\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 1105051}, {\"institution\": \"Dundee Heritage Trust\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 0}, {\"institution\": \"Elgin Museum\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 36000}, {\"institution\": \"Glasgow Museums\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 1000000}, {\"institution\": \"Heritage Doncaster\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 406750}, {\"institution\": \"Highland Folk Museum\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"social\", \"precision\": \"estimate\", \"artefact_count\": 10000}, {\"institution\": \"Leeds Museums & Galleries\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 1300000}, {\"institution\": \"Leicester Museums\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 1500000}, {\"institution\": \"Manchester Art Gallery\", \"sector\": \"regional\", \"type\": \"gallery\", \"topic\": \"art\", \"precision\": \"estimate\", \"artefact_count\": 50000}, {\"institution\": \"Edinburgh Museums\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 220000}, {\"institution\": \"Museums Northumberland\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 25000}, {\"institution\": \"Northampton Museums\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 44024}, {\"institution\": \"Orkney Museums\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 100000}, {\"institution\": \"Poole Museums\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 50000}, {\"institution\": \"Potteries Museum and Art Gallery\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"art\", \"precision\": \"estimate\", \"artefact_count\": 1000000}, {\"institution\": \"Preston Park Museum & Grounds\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"social\", \"precision\": \"estimate\", \"artefact_count\": 100000}, {\"institution\": \"Ripon Museums\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"social\", \"precision\": \"estimate\", \"artefact_count\": 9000}, {\"institution\": \"Royal Albert Memorial Museum\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 1000000}, {\"institution\": \"Salisbury Museum\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 100000}, {\"institution\": \"St Helens Borough Council\", \"sector\": \"regional\", \"type\": \"archive\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 0}, {\"institution\": \"Sunderland Museum & Winter Gardens' Collection\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 108000}, {\"institution\": \"Wakefield Museums and Castles Collections\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 111000}, {\"institution\": \"Weald and Downland Living Museum\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 15000}, {\"institution\": \"York Museums Trust\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 0}, {\"institution\": \"Victoria & Albert Museum\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"art\", \"precision\": \"estimate\", \"artefact_count\": 2800000}, {\"institution\": \"Science Museum Group\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"science\", \"precision\": \"estimate\", \"artefact_count\": 7360793}, {\"institution\": \"Museum of the Home\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"history\", \"precision\": \"estimate\", \"artefact_count\": 40000}, {\"institution\": \"Horniman Museum\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"history\", \"precision\": \"estimate\", \"artefact_count\": 350000}, {\"institution\": \"Imperial War Museums\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"history\", \"precision\": \"estimate\", \"artefact_count\": 1000000}, {\"institution\": \"National Gallery\", \"sector\": \"dcms\", \"type\": \"gallery\", \"topic\": \"art\", \"precision\": \"estimate\", \"artefact_count\": 2626}, {\"institution\": \"National Museums Liverpool\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"history\", \"precision\": \"estimate\", \"artefact_count\": 4000000}, {\"institution\": \"National Portrait Gallery\", \"sector\": \"dcms\", \"type\": \"gallery\", \"topic\": \"art\", \"precision\": \"estimate\", \"artefact_count\": 350000}, {\"institution\": \"Royal Armouries\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"history\", \"precision\": \"estimate\", \"artefact_count\": 70000}, {\"institution\": \"Royal Museums Greenwich\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"history\", \"precision\": \"estimate\", \"artefact_count\": 3000000}, {\"institution\": \"Sir John Soane's Museum\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"history\", \"precision\": \"estimate\", \"artefact_count\": 52000}, {\"institution\": \"Tate Gallery Group\", \"sector\": \"dcms\", \"type\": \"gallery\", \"topic\": \"art\", \"precision\": \"estimate\", \"artefact_count\": 70000}, {\"institution\": \"The Wallace Collection\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"art\", \"precision\": \"estimate\", \"artefact_count\": 5637}, {\"institution\": \"British Museum\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"history\", \"precision\": \"estimate\", \"artefact_count\": 8000000}]}}, {\"mode\": \"vega-lite\"});\n",
       "</script>"
      ],
      "text/plain": [
       "alt.Chart(...)"
      ]
     },
     "execution_count": 98,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "title = alt.TitleParams('Artefacts by institution type', anchor='middle')\n",
    "alt.Chart(artefacts_df,title=title).mark_bar().encode(\n",
    "    alt.Color('institution:N', sort='descending', legend=alt.Legend(orient='bottom',columns=4,symbolLimit=80)),\n",
    "    column='precision:O',\n",
    "    tooltip=['institution', 'artefact_count'],\n",
    "    x='artefact_count:Q',\n",
    "    y='type:N',\n",
    ").properties(width=900).resolve_scale(x='independent').configure(numberFormat='.2s')"
   ]
  },
  {
   "cell_type": "markdown",
   "id": "fdcd09e8-c0b8-4a8d-991a-37ddbde9318a",
   "metadata": {
    "editable": true,
    "slideshow": {
     "slide_type": ""
    },
    "tags": []
   },
   "source": [
    "## Artefacts by institution type (without Natural History)"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 87,
   "id": "6d61aac0-17c8-4178-bb49-62bf38256ac8",
   "metadata": {
    "editable": true,
    "slideshow": {
     "slide_type": ""
    },
    "tags": [
     "remove-input",
     "full-size"
    ]
   },
   "outputs": [
    {
     "data": {
      "text/html": [
       "\n",
       "<style>\n",
       "  #altair-viz-ffff6705f2824bff8a31670dc893cda5.vega-embed {\n",
       "    width: 100%;\n",
       "    display: flex;\n",
       "  }\n",
       "\n",
       "  #altair-viz-ffff6705f2824bff8a31670dc893cda5.vega-embed details,\n",
       "  #altair-viz-ffff6705f2824bff8a31670dc893cda5.vega-embed details summary {\n",
       "    position: relative;\n",
       "  }\n",
       "</style>\n",
       "<div id=\"altair-viz-ffff6705f2824bff8a31670dc893cda5\"></div>\n",
       "<script type=\"text/javascript\">\n",
       "  var VEGA_DEBUG = (typeof VEGA_DEBUG == \"undefined\") ? {} : VEGA_DEBUG;\n",
       "  (function(spec, embedOpt){\n",
       "    let outputDiv = document.currentScript.previousElementSibling;\n",
       "    if (outputDiv.id !== \"altair-viz-ffff6705f2824bff8a31670dc893cda5\") {\n",
       "      outputDiv = document.getElementById(\"altair-viz-ffff6705f2824bff8a31670dc893cda5\");\n",
       "    }\n",
       "    const paths = {\n",
       "      \"vega\": \"https://cdn.jsdelivr.net/npm/vega@5?noext\",\n",
       "      \"vega-lib\": \"https://cdn.jsdelivr.net/npm/vega-lib?noext\",\n",
       "      \"vega-lite\": \"https://cdn.jsdelivr.net/npm/vega-lite@5.17.0?noext\",\n",
       "      \"vega-embed\": \"https://cdn.jsdelivr.net/npm/vega-embed@6?noext\",\n",
       "    };\n",
       "\n",
       "    function maybeLoadScript(lib, version) {\n",
       "      var key = `${lib.replace(\"-\", \"\")}_version`;\n",
       "      return (VEGA_DEBUG[key] == version) ?\n",
       "        Promise.resolve(paths[lib]) :\n",
       "        new Promise(function(resolve, reject) {\n",
       "          var s = document.createElement('script');\n",
       "          document.getElementsByTagName(\"head\")[0].appendChild(s);\n",
       "          s.async = true;\n",
       "          s.onload = () => {\n",
       "            VEGA_DEBUG[key] = version;\n",
       "            return resolve(paths[lib]);\n",
       "          };\n",
       "          s.onerror = () => reject(`Error loading script: ${paths[lib]}`);\n",
       "          s.src = paths[lib];\n",
       "        });\n",
       "    }\n",
       "\n",
       "    function showError(err) {\n",
       "      outputDiv.innerHTML = `<div class=\"error\" style=\"color:red;\">${err}</div>`;\n",
       "      throw err;\n",
       "    }\n",
       "\n",
       "    function displayChart(vegaEmbed) {\n",
       "      vegaEmbed(outputDiv, spec, embedOpt)\n",
       "        .catch(err => showError(`Javascript Error: ${err.message}<br>This usually means there's a typo in your chart specification. See the javascript console for the full traceback.`));\n",
       "    }\n",
       "\n",
       "    if(typeof define === \"function\" && define.amd) {\n",
       "      requirejs.config({paths});\n",
       "      require([\"vega-embed\"], displayChart, err => showError(`Error loading script: ${err.message}`));\n",
       "    } else {\n",
       "      maybeLoadScript(\"vega\", \"5\")\n",
       "        .then(() => maybeLoadScript(\"vega-lite\", \"5.17.0\"))\n",
       "        .then(() => maybeLoadScript(\"vega-embed\", \"6\"))\n",
       "        .catch(showError)\n",
       "        .then(() => displayChart(vegaEmbed));\n",
       "    }\n",
       "  })({\"config\": {\"view\": {\"continuousWidth\": 300, \"continuousHeight\": 300}, \"numberFormat\": \".2s\"}, \"data\": {\"name\": \"data-d1f32ef773e5d7ce571275c2cbabb600\"}, \"mark\": {\"type\": \"bar\"}, \"encoding\": {\"color\": {\"field\": \"institution\", \"legend\": {\"columns\": 4, \"orient\": \"bottom\", \"symbolLimit\": 80}, \"sort\": \"descending\", \"type\": \"nominal\"}, \"column\": {\"field\": \"precision\", \"type\": \"ordinal\"}, \"tooltip\": [{\"field\": \"institution\", \"type\": \"nominal\"}, {\"field\": \"artefact_count\", \"type\": \"quantitative\"}], \"x\": {\"field\": \"artefact_count\", \"type\": \"quantitative\"}, \"y\": {\"field\": \"type\", \"type\": \"nominal\"}}, \"resolve\": {\"scale\": {\"x\": \"independent\"}}, \"title\": {\"text\": \"Oveview Collection Size (Artefacts) by sector (without Nature Collections)\", \"anchor\": \"middle\"}, \"width\": 900, \"$schema\": \"https://vega.github.io/schema/vega-lite/v5.17.0.json\", \"datasets\": {\"data-d1f32ef773e5d7ce571275c2cbabb600\": [{\"institution\": \"Oxford University\", \"sector\": \"university\", \"type\": \"university\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 22530000}, {\"institution\": \"University of Cambridge\", \"sector\": \"university\", \"type\": \"university\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 2000000}, {\"institution\": \"Durham University\", \"sector\": \"university\", \"type\": \"university\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 106000}, {\"institution\": \"University College London\", \"sector\": \"university\", \"type\": \"university\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 164000}, {\"institution\": \"University of Manchester\", \"sector\": \"university\", \"type\": \"university\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 8560000}, {\"institution\": \"King's College London\", \"sector\": \"university\", \"type\": \"university\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 200000}, {\"institution\": \"University of Birmingham\", \"sector\": \"university\", \"type\": \"university\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 4500000}, {\"institution\": \"Unversity of Warwick\", \"sector\": \"university\", \"type\": \"university\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 16000}, {\"institution\": \"Manchester Metropolitan Unversity\", \"sector\": \"university\", \"type\": \"university\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 0}, {\"institution\": \"Swansea University\", \"sector\": \"university\", \"type\": \"university\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 1700}, {\"institution\": \"University of Brighton\", \"sector\": \"university\", \"type\": \"university\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 50000}, {\"institution\": \"SOAS, University of London\", \"sector\": \"university\", \"type\": \"university\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 60000}, {\"institution\": \"University of Aberdeen\", \"sector\": \"university\", \"type\": \"university\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 530000}, {\"institution\": \"University of Bristol\", \"sector\": \"university\", \"type\": \"university\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 100000}, {\"institution\": \"University of Leeds\", \"sector\": \"university\", \"type\": \"university\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 350000}, {\"institution\": \"University of Sheffield\", \"sector\": \"university\", \"type\": \"university\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 30000}, {\"institution\": \"University of St Andrews\", \"sector\": \"university\", \"type\": \"university\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 200000}, {\"institution\": \"Royal College of Surgeons\", \"sector\": \"university\", \"type\": \"university\", \"topic\": \"medicine\", \"precision\": \"estimate\", \"artefact_count\": 3500}, {\"institution\": \"British Library\", \"sector\": \"library\", \"type\": \"library\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 33810000}, {\"institution\": \"Chetham's Library\", \"sector\": \"library\", \"type\": \"library\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 121041}, {\"institution\": \"Glasgow Woman's Library\", \"sector\": \"library\", \"type\": \"library\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 0}, {\"institution\": \"Lambeth Palace Library\", \"sector\": \"library\", \"type\": \"library\", \"topic\": \"theology\", \"precision\": \"estimate\", \"artefact_count\": 186200}, {\"institution\": \"National Library of Wales\", \"sector\": \"library\", \"type\": \"library\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 7540000}, {\"institution\": \"National Library of Scotland\", \"sector\": \"library\", \"type\": \"library\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 37000000}, {\"institution\": \"Amgueddfa Cymru (National Museum Wales)\", \"sector\": \"national\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 5319585}, {\"institution\": \"Historic Royal Palaces\", \"sector\": \"national\", \"type\": \"building\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 60000}, {\"institution\": \"National Football Museum\", \"sector\": \"national\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 40000}, {\"institution\": \"National Justice Museum\", \"sector\": \"national\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 40000}, {\"institution\": \"National Mining Museum Scotland\", \"sector\": \"national\", \"type\": \"museum\", \"topic\": \"industry\", \"precision\": \"estimate\", \"artefact_count\": 100000}, {\"institution\": \"National Museum of the Royal Navy\", \"sector\": \"national\", \"type\": \"museum\", \"topic\": \"maritime\", \"precision\": \"estimate\", \"artefact_count\": 2500000}, {\"institution\": \"National Museums NI\", \"sector\": \"national\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 1400000}, {\"institution\": \"National Museums Scotland\", \"sector\": \"national\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 12000000}, {\"institution\": \"National Tramway Museum\", \"sector\": \"national\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 46690}, {\"institution\": \"National Trust\", \"sector\": \"national\", \"type\": \"building\", \"topic\": \"art\", \"precision\": \"estimate\", \"artefact_count\": 1000000}, {\"institution\": \"National Trust for Scotland\", \"sector\": \"national\", \"type\": \"building\", \"topic\": \"art\", \"precision\": \"estimate\", \"artefact_count\": 300000}, {\"institution\": \"National Waterways Museum\", \"sector\": \"national\", \"type\": \"building\", \"topic\": \"transport\", \"precision\": \"estimate\", \"artefact_count\": 150000}, {\"institution\": \"Royal Collection Trust\", \"sector\": \"national\", \"type\": \"museum\", \"topic\": \"art\", \"precision\": \"estimate\", \"artefact_count\": 1000000}, {\"institution\": \"Government Art Collection\", \"sector\": \"national\", \"type\": \"museum\", \"topic\": \"art\", \"precision\": \"estimate\", \"artefact_count\": 15000}, {\"institution\": \"Historic Environment Scotland\", \"sector\": \"national\", \"type\": \"museum\", \"topic\": \"heritage\", \"precision\": \"estimate\", \"artefact_count\": 41000}, {\"institution\": \"People's History Museum\", \"sector\": \"national\", \"type\": \"museum\", \"topic\": \"social\", \"precision\": \"estimate\", \"artefact_count\": 5680}, {\"institution\": \"Portable Antiquities Scheme\", \"sector\": \"national\", \"type\": \"museum\", \"topic\": \"archaeology\", \"precision\": \"estimate\", \"artefact_count\": 1751232}, {\"institution\": \"Royal Air Force Museum\", \"sector\": \"national\", \"type\": \"museum\", \"topic\": \"military\", \"precision\": \"estimate\", \"artefact_count\": 1300000}, {\"institution\": \"Courtauld Gallery\", \"sector\": \"independent\", \"type\": \"gallery\", \"topic\": \"art\", \"precision\": \"estimate\", \"artefact_count\": 33501}, {\"institution\": \"Dulwich Picture Gallery\", \"sector\": \"independent\", \"type\": \"gallery\", \"topic\": \"art\", \"precision\": \"estimate\", \"artefact_count\": 600}, {\"institution\": \"Manchester Art Gallery\", \"sector\": \"independent\", \"type\": \"gallery\", \"topic\": \"art\", \"precision\": \"estimate\", \"artefact_count\": 46000}, {\"institution\": \"National Galleries Scotland\", \"sector\": \"independent\", \"type\": \"gallery\", \"topic\": \"art\", \"precision\": \"estimate\", \"artefact_count\": 120000}, {\"institution\": \"Bowes Museum\", \"sector\": \"independent\", \"type\": \"museum\", \"topic\": \"art\", \"precision\": \"estimate\", \"artefact_count\": 30000}, {\"institution\": \"Britten Pears\", \"sector\": \"independent\", \"type\": \"museum\", \"topic\": \"art\", \"precision\": \"estimate\", \"artefact_count\": 1200}, {\"institution\": \"Chatham Historic Dockyard\", \"sector\": \"independent\", \"type\": \"building\", \"topic\": \"maritime\", \"precision\": \"estimate\", \"artefact_count\": 70000}, {\"institution\": \"English Heritage Trust\", \"sector\": \"independent\", \"type\": \"building\", \"topic\": \"history\", \"precision\": \"estimate\", \"artefact_count\": 700000}, {\"institution\": \"Gordon Highlanders Museum\", \"sector\": \"independent\", \"type\": \"museum\", \"topic\": \"military\", \"precision\": \"estimate\", \"artefact_count\": 40000}, {\"institution\": \"Ironbridge Gorge Museum Trust\", \"sector\": \"independent\", \"type\": \"museum\", \"topic\": \"industry\", \"precision\": \"estimate\", \"artefact_count\": 400000}, {\"institution\": \"Jewish Museum London\", \"sector\": \"independent\", \"type\": \"museum\", \"topic\": \"social\", \"precision\": \"estimate\", \"artefact_count\": 40000}, {\"institution\": \"London Transport Museum\", \"sector\": \"independent\", \"type\": \"museum\", \"topic\": \"transport\", \"precision\": \"estimate\", \"artefact_count\": 500000}, {\"institution\": \"Manchester Jewish Museum\", \"sector\": \"independent\", \"type\": \"museum\", \"topic\": \"social\", \"precision\": \"estimate\", \"artefact_count\": 31000}, {\"institution\": \"Mary Rose Trust\", \"sector\": \"independent\", \"type\": \"museum\", \"topic\": \"maritime\", \"precision\": \"estimate\", \"artefact_count\": 19000}, {\"institution\": \"Media Archive for Central England (MACE)\", \"sector\": \"independent\", \"type\": \"archive\", \"topic\": \"media\", \"precision\": \"estimate\", \"artefact_count\": 65000}, {\"institution\": \"Food Museum\", \"sector\": \"independent\", \"type\": \"museum\", \"topic\": \"social\", \"precision\": \"estimate\", \"artefact_count\": 40000}, {\"institution\": \"Museum of Freemasonry\", \"sector\": \"independent\", \"type\": \"museum\", \"topic\": \"social\", \"precision\": \"estimate\", \"artefact_count\": 90000}, {\"institution\": \"Museum of Lead Mining\", \"sector\": \"independent\", \"type\": \"museum\", \"topic\": \"industry\", \"precision\": \"estimate\", \"artefact_count\": 2572}, {\"institution\": \"Museum of Scottish Railways\", \"sector\": \"independent\", \"type\": \"museum\", \"topic\": \"industry\", \"precision\": \"estimate\", \"artefact_count\": 50000}, {\"institution\": \"Paxton Trust\", \"sector\": \"independent\", \"type\": \"building\", \"topic\": \"art\", \"precision\": \"estimate\", \"artefact_count\": 3754}, {\"institution\": \"Pier Arts Centre\", \"sector\": \"independent\", \"type\": \"gallery\", \"topic\": \"art\", \"precision\": \"estimate\", \"artefact_count\": 180}, {\"institution\": \"Postal Museum\", \"sector\": \"independent\", \"type\": \"museum\", \"topic\": \"social\", \"precision\": \"estimate\", \"artefact_count\": 60000}, {\"institution\": \"Royal Artillery Museum\", \"sector\": \"independent\", \"type\": \"museum\", \"topic\": \"military\", \"precision\": \"estimate\", \"artefact_count\": 30000}, {\"institution\": \"Royal Engineers Museum\", \"sector\": \"independent\", \"type\": \"museum\", \"topic\": \"military\", \"precision\": \"estimate\", \"artefact_count\": 1000000}, {\"institution\": \"Royal Scottish Academy of Art & Architecture\", \"sector\": \"independent\", \"type\": \"museum\", \"topic\": \"art\", \"precision\": \"estimate\", \"artefact_count\": 9000}, {\"institution\": \"Aberdeenshire Council Museums\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 250000}, {\"institution\": \"Barnsley Museums\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 711400}, {\"institution\": \"Birmingham Museums Trust\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"art\", \"precision\": \"estimate\", \"artefact_count\": 800000}, {\"institution\": \"Black Country Living Museum\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"history\", \"precision\": \"estimate\", \"artefact_count\": 80000}, {\"institution\": \"Bradford District Museums & Galleries\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 837837}, {\"institution\": \"Bristol Museums\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 2000000}, {\"institution\": \"Culture Coventry\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 1000000}, {\"institution\": \"Culture Perth and Kinross\", \"sector\": \"regional\", \"type\": \"mixed\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 500000}, {\"institution\": \"Culture Trust Luton\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 1105051}, {\"institution\": \"Dundee Heritage Trust\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 0}, {\"institution\": \"Elgin Museum\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 36000}, {\"institution\": \"Glasgow Museums\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 1000000}, {\"institution\": \"Heritage Doncaster\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 406750}, {\"institution\": \"Highland Folk Museum\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"social\", \"precision\": \"estimate\", \"artefact_count\": 10000}, {\"institution\": \"Leeds Museums & Galleries\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 1300000}, {\"institution\": \"Leicester Museums\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 1500000}, {\"institution\": \"Manchester Art Gallery\", \"sector\": \"regional\", \"type\": \"gallery\", \"topic\": \"art\", \"precision\": \"estimate\", \"artefact_count\": 50000}, {\"institution\": \"Edinburgh Museums\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 220000}, {\"institution\": \"Museums Northhumberland\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 25000}, {\"institution\": \"Northhampton Museums\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 44024}, {\"institution\": \"Orkney Museums\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 100000}, {\"institution\": \"Poole Museums\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 50000}, {\"institution\": \"Potteries Museum and Art Gallery\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"arts\", \"precision\": \"estimate\", \"artefact_count\": 1000000}, {\"institution\": \"Preston Park Museum & Grounds\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"social\", \"precision\": \"estimate\", \"artefact_count\": 100000}, {\"institution\": \"Ripon Museums\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"social\", \"precision\": \"estimate\", \"artefact_count\": 9000}, {\"institution\": \"Royal Albert Memorial Museum\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 1000000}, {\"institution\": \"Salisbury Museum\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 100000}, {\"institution\": \"Victoria & Albert Museum\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"art\", \"precision\": \"estimate\", \"artefact_count\": 2800000}, {\"institution\": \"Science Museum Group\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"science\", \"precision\": \"estimate\", \"artefact_count\": 7360793}, {\"institution\": \"Museum of the Home\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"history\", \"precision\": \"estimate\", \"artefact_count\": 40000}, {\"institution\": \"Horniman Museum\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"history\", \"precision\": \"estimate\", \"artefact_count\": 350000}, {\"institution\": \"Imperial War Museums\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"history\", \"precision\": \"estimate\", \"artefact_count\": 1000000}, {\"institution\": \"National Gallery\", \"sector\": \"dcms\", \"type\": \"gallery\", \"topic\": \"art\", \"precision\": \"estimate\", \"artefact_count\": 2626}, {\"institution\": \"National Museums Liverpool\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"history\", \"precision\": \"estimate\", \"artefact_count\": 4000000}, {\"institution\": \"National Portrait Gallery\", \"sector\": \"dcms\", \"type\": \"gallery\", \"topic\": \"art\", \"precision\": \"estimate\", \"artefact_count\": 350000}, {\"institution\": \"Royal Armouries\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"history\", \"precision\": \"estimate\", \"artefact_count\": 70000}, {\"institution\": \"Royal Museums Greenwich\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"history\", \"precision\": \"estimate\", \"artefact_count\": 3000000}, {\"institution\": \"Sir John Soane's Museum\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"history\", \"precision\": \"estimate\", \"artefact_count\": 52000}, {\"institution\": \"Tate Gallery Group\", \"sector\": \"dcms\", \"type\": \"gallery\", \"topic\": \"art\", \"precision\": \"estimate\", \"artefact_count\": 70000}, {\"institution\": \"The Wallace Collection\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"art\", \"precision\": \"estimate\", \"artefact_count\": 5637}, {\"institution\": \"British Museum\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"history\", \"precision\": \"estimate\", \"artefact_count\": 8000000}]}}, {\"mode\": \"vega-lite\"});\n",
       "</script>"
      ],
      "text/plain": [
       "alt.Chart(...)"
      ]
     },
     "execution_count": 87,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "title = alt.TitleParams('Artefacts by institution type (without Nature Collections)', anchor='middle')\n",
    "alt.Chart(artefacts_non_nature_df,title=title).mark_bar().encode(\n",
    "    alt.Color('institution:N', sort='descending', legend=alt.Legend(orient='bottom',columns=4,symbolLimit=80)),\n",
    "    column='precision:O',\n",
    "    tooltip=['institution', 'artefact_count'],\n",
    "    x='artefact_count:Q',\n",
    "    y='type:N',\n",
    ").properties(width=900).resolve_scale(x='independent').configure(numberFormat='.2s')"
   ]
  },
  {
   "cell_type": "markdown",
   "id": "fffafddb-fc32-4ac4-9838-bf964c6f4341",
   "metadata": {
    "editable": true,
    "slideshow": {
     "slide_type": ""
    },
    "tags": []
   },
   "source": [
    "## Artefacts by institution and collection type"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 95,
   "id": "96d3f797-029d-4bd6-9484-1d4335ec8fdd",
   "metadata": {
    "editable": true,
    "slideshow": {
     "slide_type": ""
    },
    "tags": [
     "remove-input",
     "full-size"
    ]
   },
   "outputs": [
    {
     "data": {
      "text/html": [
       "\n",
       "<style>\n",
       "  #altair-viz-7ad0f11c2fc445d59e01b8b6ae2c6a75.vega-embed {\n",
       "    width: 100%;\n",
       "    display: flex;\n",
       "  }\n",
       "\n",
       "  #altair-viz-7ad0f11c2fc445d59e01b8b6ae2c6a75.vega-embed details,\n",
       "  #altair-viz-7ad0f11c2fc445d59e01b8b6ae2c6a75.vega-embed details summary {\n",
       "    position: relative;\n",
       "  }\n",
       "</style>\n",
       "<div id=\"altair-viz-7ad0f11c2fc445d59e01b8b6ae2c6a75\"></div>\n",
       "<script type=\"text/javascript\">\n",
       "  var VEGA_DEBUG = (typeof VEGA_DEBUG == \"undefined\") ? {} : VEGA_DEBUG;\n",
       "  (function(spec, embedOpt){\n",
       "    let outputDiv = document.currentScript.previousElementSibling;\n",
       "    if (outputDiv.id !== \"altair-viz-7ad0f11c2fc445d59e01b8b6ae2c6a75\") {\n",
       "      outputDiv = document.getElementById(\"altair-viz-7ad0f11c2fc445d59e01b8b6ae2c6a75\");\n",
       "    }\n",
       "    const paths = {\n",
       "      \"vega\": \"https://cdn.jsdelivr.net/npm/vega@5?noext\",\n",
       "      \"vega-lib\": \"https://cdn.jsdelivr.net/npm/vega-lib?noext\",\n",
       "      \"vega-lite\": \"https://cdn.jsdelivr.net/npm/vega-lite@5.17.0?noext\",\n",
       "      \"vega-embed\": \"https://cdn.jsdelivr.net/npm/vega-embed@6?noext\",\n",
       "    };\n",
       "\n",
       "    function maybeLoadScript(lib, version) {\n",
       "      var key = `${lib.replace(\"-\", \"\")}_version`;\n",
       "      return (VEGA_DEBUG[key] == version) ?\n",
       "        Promise.resolve(paths[lib]) :\n",
       "        new Promise(function(resolve, reject) {\n",
       "          var s = document.createElement('script');\n",
       "          document.getElementsByTagName(\"head\")[0].appendChild(s);\n",
       "          s.async = true;\n",
       "          s.onload = () => {\n",
       "            VEGA_DEBUG[key] = version;\n",
       "            return resolve(paths[lib]);\n",
       "          };\n",
       "          s.onerror = () => reject(`Error loading script: ${paths[lib]}`);\n",
       "          s.src = paths[lib];\n",
       "        });\n",
       "    }\n",
       "\n",
       "    function showError(err) {\n",
       "      outputDiv.innerHTML = `<div class=\"error\" style=\"color:red;\">${err}</div>`;\n",
       "      throw err;\n",
       "    }\n",
       "\n",
       "    function displayChart(vegaEmbed) {\n",
       "      vegaEmbed(outputDiv, spec, embedOpt)\n",
       "        .catch(err => showError(`Javascript Error: ${err.message}<br>This usually means there's a typo in your chart specification. See the javascript console for the full traceback.`));\n",
       "    }\n",
       "\n",
       "    if(typeof define === \"function\" && define.amd) {\n",
       "      requirejs.config({paths});\n",
       "      require([\"vega-embed\"], displayChart, err => showError(`Error loading script: ${err.message}`));\n",
       "    } else {\n",
       "      maybeLoadScript(\"vega\", \"5\")\n",
       "        .then(() => maybeLoadScript(\"vega-lite\", \"5.17.0\"))\n",
       "        .then(() => maybeLoadScript(\"vega-embed\", \"6\"))\n",
       "        .catch(showError)\n",
       "        .then(() => displayChart(vegaEmbed));\n",
       "    }\n",
       "  })({\"config\": {\"view\": {\"continuousWidth\": 300, \"continuousHeight\": 300}, \"numberFormat\": \".2s\"}, \"data\": {\"name\": \"data-a0a49f43756cc8ba5f025e1441921ad9\"}, \"mark\": {\"type\": \"bar\"}, \"encoding\": {\"color\": {\"field\": \"institution\", \"legend\": {\"columns\": 4, \"orient\": \"bottom\"}, \"type\": \"nominal\"}, \"column\": {\"field\": \"type\", \"type\": \"nominal\"}, \"order\": {\"field\": \"artefact_count\", \"type\": \"quantitative\"}, \"tooltip\": [{\"field\": \"artefact_count\", \"type\": \"quantitative\"}, {\"field\": \"institution\", \"type\": \"nominal\"}], \"x\": {\"axis\": {\"orient\": \"top\"}, \"field\": \"artefact_count\", \"type\": \"quantitative\"}, \"y\": {\"field\": \"institution\", \"type\": \"nominal\"}}, \"resolve\": {\"scale\": {\"x\": \"independent\"}}, \"title\": {\"text\": \"Artefacts per Institition by collection type\", \"anchor\": \"middle\"}, \"width\": 125, \"$schema\": \"https://vega.github.io/schema/vega-lite/v5.17.0.json\", \"datasets\": {\"data-a0a49f43756cc8ba5f025e1441921ad9\": [{\"institution\": \"Oxford University\", \"sector\": \"university\", \"type\": \"university\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 22530000}, {\"institution\": \"University of Cambridge\", \"sector\": \"university\", \"type\": \"university\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 4007000}, {\"institution\": \"Durham University\", \"sector\": \"university\", \"type\": \"university\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 106000}, {\"institution\": \"University College London\", \"sector\": \"university\", \"type\": \"university\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 164000}, {\"institution\": \"University of Manchester\", \"sector\": \"university\", \"type\": \"university\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 8560000}, {\"institution\": \"King's College London\", \"sector\": \"university\", \"type\": \"university\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 200000}, {\"institution\": \"University of Birmingham\", \"sector\": \"university\", \"type\": \"university\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 4500000}, {\"institution\": \"Unversity of Warwick\", \"sector\": \"university\", \"type\": \"university\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 16000}, {\"institution\": \"Manchester Metropolitan Unversity\", \"sector\": \"university\", \"type\": \"university\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 0}, {\"institution\": \"Swansea University\", \"sector\": \"university\", \"type\": \"university\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 1700}, {\"institution\": \"University of Brighton\", \"sector\": \"university\", \"type\": \"university\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 50000}, {\"institution\": \"SOAS, University of London\", \"sector\": \"university\", \"type\": \"university\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 60000}, {\"institution\": \"University of Aberdeen\", \"sector\": \"university\", \"type\": \"university\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 530000}, {\"institution\": \"University of Bristol\", \"sector\": \"university\", \"type\": \"university\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 100000}, {\"institution\": \"University of Leeds\", \"sector\": \"university\", \"type\": \"university\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 350000}, {\"institution\": \"University of Sheffield\", \"sector\": \"university\", \"type\": \"university\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 30000}, {\"institution\": \"University of St Andrews\", \"sector\": \"university\", \"type\": \"university\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 200000}, {\"institution\": \"Royal College of Surgeons\", \"sector\": \"university\", \"type\": \"university\", \"topic\": \"medicine\", \"precision\": \"estimate\", \"artefact_count\": 3500}, {\"institution\": \"British Library\", \"sector\": \"library\", \"type\": \"library\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 45810000}, {\"institution\": \"Chetham's Library\", \"sector\": \"library\", \"type\": \"library\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 121041}, {\"institution\": \"Glasgow Woman's Library\", \"sector\": \"library\", \"type\": \"library\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 0}, {\"institution\": \"Lambeth Palace Library\", \"sector\": \"library\", \"type\": \"library\", \"topic\": \"theology\", \"precision\": \"estimate\", \"artefact_count\": 186200}, {\"institution\": \"National Library of Wales\", \"sector\": \"library\", \"type\": \"library\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 7540000}, {\"institution\": \"National Library of Scotland\", \"sector\": \"library\", \"type\": \"library\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 37000000}, {\"institution\": \"Amgueddfa Cymru (National Museum Wales)\", \"sector\": \"national\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 5319585}, {\"institution\": \"Historic Royal Palaces\", \"sector\": \"national\", \"type\": \"building\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 60000}, {\"institution\": \"National Football Museum\", \"sector\": \"national\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 40000}, {\"institution\": \"National Justice Museum\", \"sector\": \"national\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 40000}, {\"institution\": \"National Mining Museum Scotland\", \"sector\": \"national\", \"type\": \"museum\", \"topic\": \"industry\", \"precision\": \"estimate\", \"artefact_count\": 100000}, {\"institution\": \"National Museum of the Royal Navy\", \"sector\": \"national\", \"type\": \"museum\", \"topic\": \"maritime\", \"precision\": \"estimate\", \"artefact_count\": 2500000}, {\"institution\": \"National Museums NI\", \"sector\": \"national\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 1400000}, {\"institution\": \"National Museums Scotland\", \"sector\": \"national\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 12000000}, {\"institution\": \"National Tramway Museum\", \"sector\": \"national\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 46690}, {\"institution\": \"National Trust\", \"sector\": \"national\", \"type\": \"building\", \"topic\": \"art\", \"precision\": \"estimate\", \"artefact_count\": 1000000}, {\"institution\": \"National Trust for Scotland\", \"sector\": \"national\", \"type\": \"building\", \"topic\": \"art\", \"precision\": \"estimate\", \"artefact_count\": 300000}, {\"institution\": \"National Waterways Museum\", \"sector\": \"national\", \"type\": \"building\", \"topic\": \"transport\", \"precision\": \"estimate\", \"artefact_count\": 150000}, {\"institution\": \"Government Art Collection\", \"sector\": \"national\", \"type\": \"museum\", \"topic\": \"art\", \"precision\": \"estimate\", \"artefact_count\": 15000}, {\"institution\": \"Historic Environment Scotland\", \"sector\": \"national\", \"type\": \"museum\", \"topic\": \"heritage\", \"precision\": \"estimate\", \"artefact_count\": 41000}, {\"institution\": \"People's History Museum\", \"sector\": \"national\", \"type\": \"museum\", \"topic\": \"social\", \"precision\": \"estimate\", \"artefact_count\": 5680}, {\"institution\": \"Portable Antiquities Scheme\", \"sector\": \"national\", \"type\": \"museum\", \"topic\": \"archaeology\", \"precision\": \"estimate\", \"artefact_count\": 1751232}, {\"institution\": \"Royal Air Force Museum\", \"sector\": \"national\", \"type\": \"museum\", \"topic\": \"military\", \"precision\": \"estimate\", \"artefact_count\": 1300000}, {\"institution\": \"Royal Botanic Gardens Kew\", \"sector\": \"national\", \"type\": \"museum\", \"topic\": \"nature\", \"precision\": \"estimate\", \"artefact_count\": 7000000}, {\"institution\": \"Royal Collection\", \"sector\": \"national\", \"type\": \"museum\", \"topic\": \"art\", \"precision\": \"estimate\", \"artefact_count\": 1000000}, {\"institution\": \"Staffordshire Archive and Heritage\", \"sector\": \"regional\", \"type\": \"mixed\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 0}, {\"institution\": \"Courtauld Gallery\", \"sector\": \"independent\", \"type\": \"gallery\", \"topic\": \"art\", \"precision\": \"estimate\", \"artefact_count\": 33501}, {\"institution\": \"Dulwich Picture Gallery\", \"sector\": \"independent\", \"type\": \"gallery\", \"topic\": \"art\", \"precision\": \"estimate\", \"artefact_count\": 600}, {\"institution\": \"Manchester Art Gallery\", \"sector\": \"independent\", \"type\": \"gallery\", \"topic\": \"art\", \"precision\": \"estimate\", \"artefact_count\": 46000}, {\"institution\": \"National Galleries Scotland\", \"sector\": \"independent\", \"type\": \"gallery\", \"topic\": \"art\", \"precision\": \"estimate\", \"artefact_count\": 120000}, {\"institution\": \"William Morris Gallery\", \"sector\": \"regional\", \"type\": \"gallery\", \"topic\": \"art\", \"precision\": \"estimate\", \"artefact_count\": 10000}, {\"institution\": \"Linnaean Society\", \"sector\": \"societies\", \"type\": \"society\", \"topic\": \"nature\", \"precision\": \"estimate\", \"artefact_count\": 20268}, {\"institution\": \"Bowes Museum\", \"sector\": \"independent\", \"type\": \"museum\", \"topic\": \"art\", \"precision\": \"estimate\", \"artefact_count\": 30000}, {\"institution\": \"Britten Pears\", \"sector\": \"independent\", \"type\": \"museum\", \"topic\": \"art\", \"precision\": \"estimate\", \"artefact_count\": 1200}, {\"institution\": \"Chatham Historic Dockyard\", \"sector\": \"independent\", \"type\": \"building\", \"topic\": \"maritime\", \"precision\": \"estimate\", \"artefact_count\": 70000}, {\"institution\": \"English Heritage Trust\", \"sector\": \"independent\", \"type\": \"building\", \"topic\": \"history\", \"precision\": \"estimate\", \"artefact_count\": 700000}, {\"institution\": \"Gordon Highlanders Museum\", \"sector\": \"independent\", \"type\": \"museum\", \"topic\": \"military\", \"precision\": \"estimate\", \"artefact_count\": 40000}, {\"institution\": \"Ironbridge Gorge Museum Trust\", \"sector\": \"independent\", \"type\": \"museum\", \"topic\": \"industry\", \"precision\": \"estimate\", \"artefact_count\": 400000}, {\"institution\": \"Jewish Museum London\", \"sector\": \"independent\", \"type\": \"museum\", \"topic\": \"social\", \"precision\": \"estimate\", \"artefact_count\": 40000}, {\"institution\": \"London Transport Museum\", \"sector\": \"independent\", \"type\": \"museum\", \"topic\": \"transport\", \"precision\": \"estimate\", \"artefact_count\": 500000}, {\"institution\": \"Manchester Jewish Museum\", \"sector\": \"independent\", \"type\": \"museum\", \"topic\": \"social\", \"precision\": \"estimate\", \"artefact_count\": 31000}, {\"institution\": \"Mary Rose Trust\", \"sector\": \"independent\", \"type\": \"museum\", \"topic\": \"maritime\", \"precision\": \"estimate\", \"artefact_count\": 19000}, {\"institution\": \"Media Archive for Central England (MACE)\", \"sector\": \"independent\", \"type\": \"archive\", \"topic\": \"media\", \"precision\": \"estimate\", \"artefact_count\": 65000}, {\"institution\": \"Food Museum\", \"sector\": \"independent\", \"type\": \"museum\", \"topic\": \"social\", \"precision\": \"estimate\", \"artefact_count\": 40000}, {\"institution\": \"Museum of Freemasonry\", \"sector\": \"independent\", \"type\": \"museum\", \"topic\": \"social\", \"precision\": \"estimate\", \"artefact_count\": 90000}, {\"institution\": \"Museum of Lead Mining\", \"sector\": \"independent\", \"type\": \"museum\", \"topic\": \"industry\", \"precision\": \"estimate\", \"artefact_count\": 2572}, {\"institution\": \"Museum of Scottish Railways\", \"sector\": \"independent\", \"type\": \"museum\", \"topic\": \"industry\", \"precision\": \"estimate\", \"artefact_count\": 50000}, {\"institution\": \"Paxton Trust\", \"sector\": \"independent\", \"type\": \"building\", \"topic\": \"art\", \"precision\": \"estimate\", \"artefact_count\": 3754}, {\"institution\": \"Pier Arts Centre\", \"sector\": \"independent\", \"type\": \"gallery\", \"topic\": \"art\", \"precision\": \"estimate\", \"artefact_count\": 180}, {\"institution\": \"Postal Museum\", \"sector\": \"independent\", \"type\": \"museum\", \"topic\": \"social\", \"precision\": \"estimate\", \"artefact_count\": 60000}, {\"institution\": \"Royal Artillery Museum\", \"sector\": \"independent\", \"type\": \"museum\", \"topic\": \"military\", \"precision\": \"estimate\", \"artefact_count\": 30000}, {\"institution\": \"Royal Engineers Museum\", \"sector\": \"independent\", \"type\": \"museum\", \"topic\": \"military\", \"precision\": \"estimate\", \"artefact_count\": 1000000}, {\"institution\": \"Royal Scottish Academy of Art & Architecture\", \"sector\": \"independent\", \"type\": \"museum\", \"topic\": \"art\", \"precision\": \"estimate\", \"artefact_count\": 9000}, {\"institution\": \"Scottish Fisheries Museum\", \"sector\": \"independent\", \"type\": \"museum\", \"topic\": \"maritime\", \"precision\": \"estimate\", \"artefact_count\": 66000}, {\"institution\": \"Thackray Museum of Medicine\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"medicine\", \"precision\": \"estimate\", \"artefact_count\": 75000}, {\"institution\": \"Tuillie House Museum and Art Gallery\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 1000000}, {\"institution\": \"Wellcome Collection\", \"sector\": \"independent\", \"type\": \"museum\", \"topic\": \"medicine\", \"precision\": \"estimate\", \"artefact_count\": 2250000}, {\"institution\": \"Wordsworth Museum Collection\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"literature\", \"precision\": \"estimate\", \"artefact_count\": 68000}, {\"institution\": \"Aberdeenshire Council Museums\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 250000}, {\"institution\": \"Barnsley Museums\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 711400}, {\"institution\": \"Birmingham Museums Trust\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"art\", \"precision\": \"estimate\", \"artefact_count\": 800000}, {\"institution\": \"Black Country Living Museum\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"history\", \"precision\": \"estimate\", \"artefact_count\": 80000}, {\"institution\": \"Bradford District Museums & Galleries\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 837837}, {\"institution\": \"Bristol Museums\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 2000000}, {\"institution\": \"Culture Coventry\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 1000000}, {\"institution\": \"Culture Perth and Kinross\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 500000}, {\"institution\": \"Culture Trust Luton\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 1105051}, {\"institution\": \"Dundee Heritage Trust\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 0}, {\"institution\": \"Elgin Museum\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 36000}, {\"institution\": \"Glasgow Museums\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 1000000}, {\"institution\": \"Heritage Doncaster\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 406750}, {\"institution\": \"Highland Folk Museum\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"social\", \"precision\": \"estimate\", \"artefact_count\": 10000}, {\"institution\": \"Leeds Museums & Galleries\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 1300000}, {\"institution\": \"Leicester Museums\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 1500000}, {\"institution\": \"Manchester Art Gallery\", \"sector\": \"regional\", \"type\": \"gallery\", \"topic\": \"art\", \"precision\": \"estimate\", \"artefact_count\": 50000}, {\"institution\": \"Edinburgh Museums\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 220000}, {\"institution\": \"Museums Northumberland\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 25000}, {\"institution\": \"Northampton Museums\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 44024}, {\"institution\": \"Orkney Museums\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 100000}, {\"institution\": \"Poole Museums\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 50000}, {\"institution\": \"Potteries Museum and Art Gallery\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"art\", \"precision\": \"estimate\", \"artefact_count\": 1000000}, {\"institution\": \"Preston Park Museum & Grounds\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"social\", \"precision\": \"estimate\", \"artefact_count\": 100000}, {\"institution\": \"Ripon Museums\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"social\", \"precision\": \"estimate\", \"artefact_count\": 9000}, {\"institution\": \"Royal Albert Memorial Museum\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 1000000}, {\"institution\": \"Salisbury Museum\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 100000}, {\"institution\": \"St Helens Borough Council\", \"sector\": \"regional\", \"type\": \"archive\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 0}, {\"institution\": \"Sunderland Museum & Winter Gardens' Collection\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 108000}, {\"institution\": \"Wakefield Museums and Castles Collections\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 111000}, {\"institution\": \"Weald and Downland Living Museum\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 15000}, {\"institution\": \"York Museums Trust\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 0}, {\"institution\": \"Victoria & Albert Museum\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"art\", \"precision\": \"estimate\", \"artefact_count\": 2800000}, {\"institution\": \"Science Museum Group\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"science\", \"precision\": \"estimate\", \"artefact_count\": 7360793}, {\"institution\": \"Museum of the Home\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"history\", \"precision\": \"estimate\", \"artefact_count\": 40000}, {\"institution\": \"Horniman Museum\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"history\", \"precision\": \"estimate\", \"artefact_count\": 350000}, {\"institution\": \"Imperial War Museums\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"history\", \"precision\": \"estimate\", \"artefact_count\": 1000000}, {\"institution\": \"National Gallery\", \"sector\": \"dcms\", \"type\": \"gallery\", \"topic\": \"art\", \"precision\": \"estimate\", \"artefact_count\": 2626}, {\"institution\": \"National Museums Liverpool\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"history\", \"precision\": \"estimate\", \"artefact_count\": 4000000}, {\"institution\": \"National Portrait Gallery\", \"sector\": \"dcms\", \"type\": \"gallery\", \"topic\": \"art\", \"precision\": \"estimate\", \"artefact_count\": 350000}, {\"institution\": \"Royal Armouries\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"history\", \"precision\": \"estimate\", \"artefact_count\": 70000}, {\"institution\": \"Royal Museums Greenwich\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"history\", \"precision\": \"estimate\", \"artefact_count\": 3000000}, {\"institution\": \"Sir John Soane's Museum\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"history\", \"precision\": \"estimate\", \"artefact_count\": 52000}, {\"institution\": \"Tate Gallery Group\", \"sector\": \"dcms\", \"type\": \"gallery\", \"topic\": \"art\", \"precision\": \"estimate\", \"artefact_count\": 70000}, {\"institution\": \"The Wallace Collection\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"art\", \"precision\": \"estimate\", \"artefact_count\": 5637}, {\"institution\": \"British Museum\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"history\", \"precision\": \"estimate\", \"artefact_count\": 8000000}]}}, {\"mode\": \"vega-lite\"});\n",
       "</script>"
      ],
      "text/plain": [
       "alt.Chart(...)"
      ]
     },
     "execution_count": 95,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "import altair as alt\n",
    "title = alt.TitleParams('Artefacts per Institition by collection type', anchor='middle')\n",
    "alt.Chart(artefacts_df, title=title, width=125).mark_bar().encode(\n",
    "    alt.Color('institution:N', legend=alt.Legend(orient='bottom',columns=4)),\n",
    "    alt.X('artefact_count', axis=alt.Axis(orient='top')),\n",
    "    y='institution',\n",
    "    column='type',\n",
    "    tooltip=['artefact_count', 'institution'],\n",
    "    order='artefact_count:Q'\n",
    ").configure(numberFormat='.2s').resolve_scale(x='independent')"
   ]
  },
  {
   "cell_type": "markdown",
   "id": "d5bf1b30-d1d4-45cf-9d1e-413134e72c9a",
   "metadata": {
    "editable": true,
    "slideshow": {
     "slide_type": ""
    },
    "tags": []
   },
   "source": [
    "## Artefacts per instition and collection type (without natural history)"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 78,
   "id": "f75e26ab-f708-4a93-a4bb-ff710291e97e",
   "metadata": {
    "editable": true,
    "slideshow": {
     "slide_type": ""
    },
    "tags": [
     "remove-input",
     "full-size"
    ]
   },
   "outputs": [
    {
     "data": {
      "text/html": [
       "\n",
       "<style>\n",
       "  #altair-viz-fb76ab10bddb491186a2ff45947a2bb1.vega-embed {\n",
       "    width: 100%;\n",
       "    display: flex;\n",
       "  }\n",
       "\n",
       "  #altair-viz-fb76ab10bddb491186a2ff45947a2bb1.vega-embed details,\n",
       "  #altair-viz-fb76ab10bddb491186a2ff45947a2bb1.vega-embed details summary {\n",
       "    position: relative;\n",
       "  }\n",
       "</style>\n",
       "<div id=\"altair-viz-fb76ab10bddb491186a2ff45947a2bb1\"></div>\n",
       "<script type=\"text/javascript\">\n",
       "  var VEGA_DEBUG = (typeof VEGA_DEBUG == \"undefined\") ? {} : VEGA_DEBUG;\n",
       "  (function(spec, embedOpt){\n",
       "    let outputDiv = document.currentScript.previousElementSibling;\n",
       "    if (outputDiv.id !== \"altair-viz-fb76ab10bddb491186a2ff45947a2bb1\") {\n",
       "      outputDiv = document.getElementById(\"altair-viz-fb76ab10bddb491186a2ff45947a2bb1\");\n",
       "    }\n",
       "    const paths = {\n",
       "      \"vega\": \"https://cdn.jsdelivr.net/npm/vega@5?noext\",\n",
       "      \"vega-lib\": \"https://cdn.jsdelivr.net/npm/vega-lib?noext\",\n",
       "      \"vega-lite\": \"https://cdn.jsdelivr.net/npm/vega-lite@5.17.0?noext\",\n",
       "      \"vega-embed\": \"https://cdn.jsdelivr.net/npm/vega-embed@6?noext\",\n",
       "    };\n",
       "\n",
       "    function maybeLoadScript(lib, version) {\n",
       "      var key = `${lib.replace(\"-\", \"\")}_version`;\n",
       "      return (VEGA_DEBUG[key] == version) ?\n",
       "        Promise.resolve(paths[lib]) :\n",
       "        new Promise(function(resolve, reject) {\n",
       "          var s = document.createElement('script');\n",
       "          document.getElementsByTagName(\"head\")[0].appendChild(s);\n",
       "          s.async = true;\n",
       "          s.onload = () => {\n",
       "            VEGA_DEBUG[key] = version;\n",
       "            return resolve(paths[lib]);\n",
       "          };\n",
       "          s.onerror = () => reject(`Error loading script: ${paths[lib]}`);\n",
       "          s.src = paths[lib];\n",
       "        });\n",
       "    }\n",
       "\n",
       "    function showError(err) {\n",
       "      outputDiv.innerHTML = `<div class=\"error\" style=\"color:red;\">${err}</div>`;\n",
       "      throw err;\n",
       "    }\n",
       "\n",
       "    function displayChart(vegaEmbed) {\n",
       "      vegaEmbed(outputDiv, spec, embedOpt)\n",
       "        .catch(err => showError(`Javascript Error: ${err.message}<br>This usually means there's a typo in your chart specification. See the javascript console for the full traceback.`));\n",
       "    }\n",
       "\n",
       "    if(typeof define === \"function\" && define.amd) {\n",
       "      requirejs.config({paths});\n",
       "      require([\"vega-embed\"], displayChart, err => showError(`Error loading script: ${err.message}`));\n",
       "    } else {\n",
       "      maybeLoadScript(\"vega\", \"5\")\n",
       "        .then(() => maybeLoadScript(\"vega-lite\", \"5.17.0\"))\n",
       "        .then(() => maybeLoadScript(\"vega-embed\", \"6\"))\n",
       "        .catch(showError)\n",
       "        .then(() => displayChart(vegaEmbed));\n",
       "    }\n",
       "  })({\"config\": {\"view\": {\"continuousWidth\": 300, \"continuousHeight\": 300}, \"numberFormat\": \".2s\"}, \"data\": {\"name\": \"data-d1f32ef773e5d7ce571275c2cbabb600\"}, \"mark\": {\"type\": \"bar\"}, \"encoding\": {\"color\": {\"field\": \"institution\", \"legend\": {\"columns\": 4, \"orient\": \"bottom\"}, \"type\": \"nominal\"}, \"column\": {\"field\": \"type\", \"type\": \"nominal\"}, \"order\": {\"field\": \"artefact_count\", \"type\": \"quantitative\"}, \"tooltip\": {\"field\": \"artefact_count\", \"type\": \"quantitative\"}, \"x\": {\"axis\": {\"orient\": \"top\"}, \"field\": \"artefact_count\", \"type\": \"quantitative\"}, \"y\": {\"field\": \"institution\", \"type\": \"nominal\"}}, \"resolve\": {\"scale\": {\"x\": \"independent\"}}, \"title\": {\"text\": \"Artefacts per Institition (by collection type, without specimen collections\", \"anchor\": \"middle\"}, \"width\": 125, \"$schema\": \"https://vega.github.io/schema/vega-lite/v5.17.0.json\", \"datasets\": {\"data-d1f32ef773e5d7ce571275c2cbabb600\": [{\"institution\": \"Oxford University\", \"sector\": \"university\", \"type\": \"university\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 22530000}, {\"institution\": \"University of Cambridge\", \"sector\": \"university\", \"type\": \"university\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 2000000}, {\"institution\": \"Durham University\", \"sector\": \"university\", \"type\": \"university\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 106000}, {\"institution\": \"University College London\", \"sector\": \"university\", \"type\": \"university\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 164000}, {\"institution\": \"University of Manchester\", \"sector\": \"university\", \"type\": \"university\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 8560000}, {\"institution\": \"King's College London\", \"sector\": \"university\", \"type\": \"university\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 200000}, {\"institution\": \"University of Birmingham\", \"sector\": \"university\", \"type\": \"university\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 4500000}, {\"institution\": \"Unversity of Warwick\", \"sector\": \"university\", \"type\": \"university\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 16000}, {\"institution\": \"Manchester Metropolitan Unversity\", \"sector\": \"university\", \"type\": \"university\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 0}, {\"institution\": \"Swansea University\", \"sector\": \"university\", \"type\": \"university\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 1700}, {\"institution\": \"University of Brighton\", \"sector\": \"university\", \"type\": \"university\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 50000}, {\"institution\": \"SOAS, University of London\", \"sector\": \"university\", \"type\": \"university\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 60000}, {\"institution\": \"University of Aberdeen\", \"sector\": \"university\", \"type\": \"university\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 530000}, {\"institution\": \"University of Bristol\", \"sector\": \"university\", \"type\": \"university\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 100000}, {\"institution\": \"University of Leeds\", \"sector\": \"university\", \"type\": \"university\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 350000}, {\"institution\": \"University of Sheffield\", \"sector\": \"university\", \"type\": \"university\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 30000}, {\"institution\": \"University of St Andrews\", \"sector\": \"university\", \"type\": \"university\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 200000}, {\"institution\": \"Royal College of Surgeons\", \"sector\": \"university\", \"type\": \"university\", \"topic\": \"medicine\", \"precision\": \"estimate\", \"artefact_count\": 3500}, {\"institution\": \"British Library\", \"sector\": \"library\", \"type\": \"library\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 33810000}, {\"institution\": \"Chetham's Library\", \"sector\": \"library\", \"type\": \"library\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 121041}, {\"institution\": \"Glasgow Woman's Library\", \"sector\": \"library\", \"type\": \"library\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 0}, {\"institution\": \"Lambeth Palace Library\", \"sector\": \"library\", \"type\": \"library\", \"topic\": \"theology\", \"precision\": \"estimate\", \"artefact_count\": 186200}, {\"institution\": \"National Library of Wales\", \"sector\": \"library\", \"type\": \"library\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 7540000}, {\"institution\": \"National Library of Scotland\", \"sector\": \"library\", \"type\": \"library\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 37000000}, {\"institution\": \"Amgueddfa Cymru (National Museum Wales)\", \"sector\": \"national\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 5319585}, {\"institution\": \"Historic Royal Palaces\", \"sector\": \"national\", \"type\": \"building\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 60000}, {\"institution\": \"National Football Museum\", \"sector\": \"national\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 40000}, {\"institution\": \"National Justice Museum\", \"sector\": \"national\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 40000}, {\"institution\": \"National Mining Museum Scotland\", \"sector\": \"national\", \"type\": \"museum\", \"topic\": \"industry\", \"precision\": \"estimate\", \"artefact_count\": 100000}, {\"institution\": \"National Museum of the Royal Navy\", \"sector\": \"national\", \"type\": \"museum\", \"topic\": \"maritime\", \"precision\": \"estimate\", \"artefact_count\": 2500000}, {\"institution\": \"National Museums NI\", \"sector\": \"national\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 1400000}, {\"institution\": \"National Museums Scotland\", \"sector\": \"national\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 12000000}, {\"institution\": \"National Tramway Museum\", \"sector\": \"national\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 46690}, {\"institution\": \"National Trust\", \"sector\": \"national\", \"type\": \"building\", \"topic\": \"art\", \"precision\": \"estimate\", \"artefact_count\": 1000000}, {\"institution\": \"National Trust for Scotland\", \"sector\": \"national\", \"type\": \"building\", \"topic\": \"art\", \"precision\": \"estimate\", \"artefact_count\": 300000}, {\"institution\": \"National Waterways Museum\", \"sector\": \"national\", \"type\": \"building\", \"topic\": \"transport\", \"precision\": \"estimate\", \"artefact_count\": 150000}, {\"institution\": \"Royal Collection Trust\", \"sector\": \"national\", \"type\": \"museum\", \"topic\": \"art\", \"precision\": \"estimate\", \"artefact_count\": 1000000}, {\"institution\": \"Government Art Collection\", \"sector\": \"national\", \"type\": \"museum\", \"topic\": \"art\", \"precision\": \"estimate\", \"artefact_count\": 15000}, {\"institution\": \"Historic Environment Scotland\", \"sector\": \"national\", \"type\": \"museum\", \"topic\": \"heritage\", \"precision\": \"estimate\", \"artefact_count\": 41000}, {\"institution\": \"People's History Museum\", \"sector\": \"national\", \"type\": \"museum\", \"topic\": \"social\", \"precision\": \"estimate\", \"artefact_count\": 5680}, {\"institution\": \"Portable Antiquities Scheme\", \"sector\": \"national\", \"type\": \"museum\", \"topic\": \"archaeology\", \"precision\": \"estimate\", \"artefact_count\": 1751232}, {\"institution\": \"Royal Air Force Museum\", \"sector\": \"national\", \"type\": \"museum\", \"topic\": \"military\", \"precision\": \"estimate\", \"artefact_count\": 1300000}, {\"institution\": \"Courtauld Gallery\", \"sector\": \"independent\", \"type\": \"gallery\", \"topic\": \"art\", \"precision\": \"estimate\", \"artefact_count\": 33501}, {\"institution\": \"Dulwich Picture Gallery\", \"sector\": \"independent\", \"type\": \"gallery\", \"topic\": \"art\", \"precision\": \"estimate\", \"artefact_count\": 600}, {\"institution\": \"Manchester Art Gallery\", \"sector\": \"independent\", \"type\": \"gallery\", \"topic\": \"art\", \"precision\": \"estimate\", \"artefact_count\": 46000}, {\"institution\": \"National Galleries Scotland\", \"sector\": \"independent\", \"type\": \"gallery\", \"topic\": \"art\", \"precision\": \"estimate\", \"artefact_count\": 120000}, {\"institution\": \"Bowes Museum\", \"sector\": \"independent\", \"type\": \"museum\", \"topic\": \"art\", \"precision\": \"estimate\", \"artefact_count\": 30000}, {\"institution\": \"Britten Pears\", \"sector\": \"independent\", \"type\": \"museum\", \"topic\": \"art\", \"precision\": \"estimate\", \"artefact_count\": 1200}, {\"institution\": \"Chatham Historic Dockyard\", \"sector\": \"independent\", \"type\": \"building\", \"topic\": \"maritime\", \"precision\": \"estimate\", \"artefact_count\": 70000}, {\"institution\": \"English Heritage Trust\", \"sector\": \"independent\", \"type\": \"building\", \"topic\": \"history\", \"precision\": \"estimate\", \"artefact_count\": 700000}, {\"institution\": \"Gordon Highlanders Museum\", \"sector\": \"independent\", \"type\": \"museum\", \"topic\": \"military\", \"precision\": \"estimate\", \"artefact_count\": 40000}, {\"institution\": \"Ironbridge Gorge Museum Trust\", \"sector\": \"independent\", \"type\": \"museum\", \"topic\": \"industry\", \"precision\": \"estimate\", \"artefact_count\": 400000}, {\"institution\": \"Jewish Museum London\", \"sector\": \"independent\", \"type\": \"museum\", \"topic\": \"social\", \"precision\": \"estimate\", \"artefact_count\": 40000}, {\"institution\": \"London Transport Museum\", \"sector\": \"independent\", \"type\": \"museum\", \"topic\": \"transport\", \"precision\": \"estimate\", \"artefact_count\": 500000}, {\"institution\": \"Manchester Jewish Museum\", \"sector\": \"independent\", \"type\": \"museum\", \"topic\": \"social\", \"precision\": \"estimate\", \"artefact_count\": 31000}, {\"institution\": \"Mary Rose Trust\", \"sector\": \"independent\", \"type\": \"museum\", \"topic\": \"maritime\", \"precision\": \"estimate\", \"artefact_count\": 19000}, {\"institution\": \"Media Archive for Central England (MACE)\", \"sector\": \"independent\", \"type\": \"archive\", \"topic\": \"media\", \"precision\": \"estimate\", \"artefact_count\": 65000}, {\"institution\": \"Food Museum\", \"sector\": \"independent\", \"type\": \"museum\", \"topic\": \"social\", \"precision\": \"estimate\", \"artefact_count\": 40000}, {\"institution\": \"Museum of Freemasonry\", \"sector\": \"independent\", \"type\": \"museum\", \"topic\": \"social\", \"precision\": \"estimate\", \"artefact_count\": 90000}, {\"institution\": \"Museum of Lead Mining\", \"sector\": \"independent\", \"type\": \"museum\", \"topic\": \"industry\", \"precision\": \"estimate\", \"artefact_count\": 2572}, {\"institution\": \"Museum of Scottish Railways\", \"sector\": \"independent\", \"type\": \"museum\", \"topic\": \"industry\", \"precision\": \"estimate\", \"artefact_count\": 50000}, {\"institution\": \"Paxton Trust\", \"sector\": \"independent\", \"type\": \"building\", \"topic\": \"art\", \"precision\": \"estimate\", \"artefact_count\": 3754}, {\"institution\": \"Pier Arts Centre\", \"sector\": \"independent\", \"type\": \"gallery\", \"topic\": \"art\", \"precision\": \"estimate\", \"artefact_count\": 180}, {\"institution\": \"Postal Museum\", \"sector\": \"independent\", \"type\": \"museum\", \"topic\": \"social\", \"precision\": \"estimate\", \"artefact_count\": 60000}, {\"institution\": \"Royal Artillery Museum\", \"sector\": \"independent\", \"type\": \"museum\", \"topic\": \"military\", \"precision\": \"estimate\", \"artefact_count\": 30000}, {\"institution\": \"Royal Engineers Museum\", \"sector\": \"independent\", \"type\": \"museum\", \"topic\": \"military\", \"precision\": \"estimate\", \"artefact_count\": 1000000}, {\"institution\": \"Royal Scottish Academy of Art & Architecture\", \"sector\": \"independent\", \"type\": \"museum\", \"topic\": \"art\", \"precision\": \"estimate\", \"artefact_count\": 9000}, {\"institution\": \"Aberdeenshire Council Museums\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 250000}, {\"institution\": \"Barnsley Museums\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 711400}, {\"institution\": \"Birmingham Museums Trust\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"art\", \"precision\": \"estimate\", \"artefact_count\": 800000}, {\"institution\": \"Black Country Living Museum\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"history\", \"precision\": \"estimate\", \"artefact_count\": 80000}, {\"institution\": \"Bradford District Museums & Galleries\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 837837}, {\"institution\": \"Bristol Museums\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 2000000}, {\"institution\": \"Culture Coventry\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 1000000}, {\"institution\": \"Culture Perth and Kinross\", \"sector\": \"regional\", \"type\": \"mixed\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 500000}, {\"institution\": \"Culture Trust Luton\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 1105051}, {\"institution\": \"Dundee Heritage Trust\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 0}, {\"institution\": \"Elgin Museum\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 36000}, {\"institution\": \"Glasgow Museums\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 1000000}, {\"institution\": \"Heritage Doncaster\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 406750}, {\"institution\": \"Highland Folk Museum\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"social\", \"precision\": \"estimate\", \"artefact_count\": 10000}, {\"institution\": \"Leeds Museums & Galleries\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 1300000}, {\"institution\": \"Leicester Museums\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 1500000}, {\"institution\": \"Manchester Art Gallery\", \"sector\": \"regional\", \"type\": \"gallery\", \"topic\": \"art\", \"precision\": \"estimate\", \"artefact_count\": 50000}, {\"institution\": \"Edinburgh Museums\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 220000}, {\"institution\": \"Museums Northhumberland\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 25000}, {\"institution\": \"Northhampton Museums\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 44024}, {\"institution\": \"Orkney Museums\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 100000}, {\"institution\": \"Poole Museums\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 50000}, {\"institution\": \"Potteries Museum and Art Gallery\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"arts\", \"precision\": \"estimate\", \"artefact_count\": 1000000}, {\"institution\": \"Preston Park Museum & Grounds\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"social\", \"precision\": \"estimate\", \"artefact_count\": 100000}, {\"institution\": \"Ripon Museums\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"social\", \"precision\": \"estimate\", \"artefact_count\": 9000}, {\"institution\": \"Royal Albert Memorial Museum\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 1000000}, {\"institution\": \"Salisbury Museum\", \"sector\": \"regional\", \"type\": \"museum\", \"topic\": \"mixed\", \"precision\": \"estimate\", \"artefact_count\": 100000}, {\"institution\": \"Victoria & Albert Museum\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"art\", \"precision\": \"estimate\", \"artefact_count\": 2800000}, {\"institution\": \"Science Museum Group\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"science\", \"precision\": \"estimate\", \"artefact_count\": 7360793}, {\"institution\": \"Museum of the Home\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"history\", \"precision\": \"estimate\", \"artefact_count\": 40000}, {\"institution\": \"Horniman Museum\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"history\", \"precision\": \"estimate\", \"artefact_count\": 350000}, {\"institution\": \"Imperial War Museums\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"history\", \"precision\": \"estimate\", \"artefact_count\": 1000000}, {\"institution\": \"National Gallery\", \"sector\": \"dcms\", \"type\": \"gallery\", \"topic\": \"art\", \"precision\": \"estimate\", \"artefact_count\": 2626}, {\"institution\": \"National Museums Liverpool\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"history\", \"precision\": \"estimate\", \"artefact_count\": 4000000}, {\"institution\": \"National Portrait Gallery\", \"sector\": \"dcms\", \"type\": \"gallery\", \"topic\": \"art\", \"precision\": \"estimate\", \"artefact_count\": 350000}, {\"institution\": \"Royal Armouries\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"history\", \"precision\": \"estimate\", \"artefact_count\": 70000}, {\"institution\": \"Royal Museums Greenwich\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"history\", \"precision\": \"estimate\", \"artefact_count\": 3000000}, {\"institution\": \"Sir John Soane's Museum\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"history\", \"precision\": \"estimate\", \"artefact_count\": 52000}, {\"institution\": \"Tate Gallery Group\", \"sector\": \"dcms\", \"type\": \"gallery\", \"topic\": \"art\", \"precision\": \"estimate\", \"artefact_count\": 70000}, {\"institution\": \"The Wallace Collection\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"art\", \"precision\": \"estimate\", \"artefact_count\": 5637}, {\"institution\": \"British Museum\", \"sector\": \"dcms\", \"type\": \"museum\", \"topic\": \"history\", \"precision\": \"estimate\", \"artefact_count\": 8000000}]}}, {\"mode\": \"vega-lite\"});\n",
       "</script>"
      ],
      "text/plain": [
       "alt.Chart(...)"
      ]
     },
     "execution_count": 78,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "import altair as alt\n",
    "\n",
    "artefacts_non_nature_df = artefacts_df.loc[artefacts_df['topic'] != 'nature']\n",
    "\n",
    "title = alt.TitleParams('Artefacts per Institition (by collection type, without specimen collections', anchor='middle')\n",
    "alt.Chart(artefacts_non_nature_df, title=title, width=125).mark_bar().encode(\n",
    "    alt.Color('institution:N', legend=alt.Legend(orient='bottom',columns=4)),\n",
    "    alt.X('artefact_count', axis=alt.Axis(orient='top')),\n",
    "    y='institution',\n",
    "    column='type',\n",
    "    tooltip=['institution', 'artefact_count'],\n",
    "    order='artefact_count:Q'\n",
    ").configure(numberFormat='.2s').resolve_scale(x='independent')"
   ]
  }
 ],
 "metadata": {
  "kernelspec": {
   "display_name": "Python 3 (ipykernel)",
   "language": "python",
   "name": "python3"
  },
  "language_info": {
   "codemirror_mode": {
    "name": "ipython",
    "version": 3
   },
   "file_extension": ".py",
   "mimetype": "text/x-python",
   "name": "python",
   "nbconvert_exporter": "python",
   "pygments_lexer": "ipython3",
   "version": "3.9.18"
  }
 },
 "nbformat": 4,
 "nbformat_minor": 5
}
